#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   treefoam.py
#
#       OpenFOAM用のランチャ
#
#       programed by s.fujii
#       11/04/15    新規作成（ver 1.0）
#          05/08    editBoundary(grid)を追加（ver 1.1）
#          08/17    項目のダブルクリックでフォルダopen、plotWatcher追加（ver1.2）
#       12/01/01    ﾊﾞｸﾞ修正
#                   reloadで数字ﾌｫﾙﾀﾞが存在しない場合、ｴﾗｰが発生していた
#                   gridEditor:boundaryFieldにｺﾒﾝﾄ文がある時、正常に書き込めなかった
#                   フォルダの追加削除を可能にした
#       12/01/03    gridEditorでpatchの削除を可能にした
#          01/06    ﾊﾞｸﾞ修正（ﾌｫﾙﾀﾞ名変更時、修正しない時にｴﾗｰが発生）
#          01/08    gridEditorでのpatch名の変更を可能にした
#          01/15    ﾊﾞｸﾞ修正（最初のpatch削除できなかった）。helpを表示
#          01/17    ﾊﾞｸﾞ修正（patch削除時ｺﾞﾐが残る）、ﾓﾃﾞﾙ倍率の保存方法修正
#          01/21    gridEditorｺﾏﾝﾄﾞ追加。これに伴いﾗﾝﾁｬを修正（ver1.21）
#          01/22    caseOpen, cntDictOpenボタン追加
#          02/05    windowClose時に終了処理追加
#          02/12    gridEditor:patch変更、削除時にglobal変数設定（ﾊﾞｸﾞ修正）
#          02/13    folder削除時のﾊﾞｸﾞ修正(削除するfolderが解析Caseの場合ｴﾗｰ発生)
#          02/18    treefoam,gridEditorにﾒﾆｭｰｷｰとｼｮｰﾄｶｯﾄkey追加
#          02/19    folderのｺﾋﾟｰ、貼付けを追加（ver1.22)
#          02/25    gridEditor:cellData読込みをtimerEventで実施
#          02/26    windowSizeを保存する様に変更。ﾌｫﾙﾀﾞ削除時のﾊﾞｸﾞ修正
#          03/10    iconNameを変数に変更
#          03/25    gridEditor直接起動メニューとアイコンを追加
#          04/08    フォントサイズをsystemFontのサイズに設定。copy時にgaugeを使用。
#                   colWidthを保存。gridEditor:save時にgaugeを使用。
#          04/22    gridEditor:fieldの表示設定追加（ver1.23)
#          04/23    gridEditor:読込、保存時のｴﾗｰに対応
#          05/01    editorの設定追加、HD残り容量表示、表示を縞模様表示に、並列計算追加
#                   gridEditorの起動方法変更
#          05/13    folderCopyを修正（同じfolderを同じ場所に10回以上copyは禁止）
#          05/20    folder削除を2回繰り返すとｴﾗｰ発生していた事を修正。
#                   rootDirは削除できない様に修正。
#                   configTreeFoamの修正用ｺﾏﾝﾄﾞ追加（ver1.24）
#          05/21    BOLD表示を削除（文字長さが変わる為）
#          06/02    openGridEditorDialogを修正（.displayFieldの読込み）
#          06/09    「gridEditor」ｺﾏﾝﾄﾞを修正
#          06/24    caseコピーを追加。folder複数選択可能に設定。deleteをゴミ箱へ変更。
#          07/15    popupﾒﾆｭｰを充実（ver1.25）
#          07/21    gridEDitor:第1番目のpatch名変更時のｴﾗｰ対応
#          08/05    gridEditor:最大cell内行数を変更
#          08/11    gridEditor:patch名変更・削除時、cell変更チェック追加
#          08/14    gridEditor:field名表示部修正（field削除時、表示のみ削除できなかった）
#          08/16    gridEditor:初期化時にcell(0,0),(1,0)のｸﾘｱを追加
#          08/25    gridEditor:close時に「保存して終了」を追加
#          09/11    MakePatchDialog.py:OF-2.1.0以降createBafflesが変わった為、これに対応
#          09/13    popupﾒﾆｭｰを変更（ver1.26）
#          09/17    pyTreeFoamのバグ修正
#          09/23    gridEditorのバグ修正,importするmoduleを整理(segmentation fault対策）
#                   HelyxOS,結果folder削除ﾎﾞﾀﾝを追加（ver1.30）
#          10/13    結果フォルダの削除を修正（選択caseと解析caseが違っている時確認する）
#          10/14    toolTip表示を追加
#          10/29    frameのimportを廃止（dialogは残す）
#          11/03    runParallel:接続状態確認ルーチン修正
#          11/05    editBoundaryConditionDialogを修正（ﾊﾞｸﾞ）
#          11/07    caseCopyを修正（並列処理のcaseCopy時processor内の全てをcopyしていた）
#                   renameで解析caseのdirが変わる場合、解析case無くなるｴﾗｰを修正
#                   gridEditor:空patch追加,internalFieldｸﾘｱのｺﾏﾝﾄﾞを設定
#          11/12    caseCopyを修正（並列処理のcaseCopy時processor内のcopy処理修正）
#          11/17    runHelyxOS:caseDir, stlDir, eMeshDirを設定した上でHelyxOSを起動
#          11/21    runHelyxOS:newCaseを追加（ver1.31）
#          11/24    並列計算:processor内へのfaileｺﾋﾟｰ、削除追加
#          12/09    並列計算:multiRegionのバグ取り
#          12/16    topoSetEditor:cominedAction追加
#          12/17    topoSetEditor:表示・非表示設定修正
#       13/01/01    内部patch作成:OF-2.0に対応（ver1.32）
#          01/06    multiRegion内のfaile操作を追加
#          01/22    makeRunTopoSetを修正
#          01/27    topoSetEditorを修正（regionToCellがセットできる様に修正）
#          01/28    nRunningTreeFoamの場所を「/data」に変更
#          01/31    ﾊﾞｸﾞ修正（時々ダブってfolderが表示される事を修正
#          02/03    topoSetEditorに「newCellToFace」を追加
#          02/07    端末起動時にunicodeｴﾗｰ発生する場合あり、修正
#          02/10    folderOpenDDialogでcurrentDirを表示するように修正
#          02/11    treefoamnのiconをfileのimageに変更
#          02/17    gridEditor:cell内容に応じてﾌｫﾝﾄ色を変更
#          03/03    gridEditor:バグ修正（boundary誤読み込み発生）
#          03/04    pyTreeFoam:バグ修正（boundary誤書き込み発生）
#          03/10    gridEditor:patchContの読み込み修正
#          03/16    TreeFoam,gridEditorにsystemFont色を変数で設定
#                   並列時、multiRegion判定をcellToRegionからregionPoperties有無に変更
#          04/06    「新しいcaseの作成」を追加（ver1.33）
#          04/07    menuの配置を変更（ver1.40）
#          04/14    setMultiRegionのアイコン追加、解析caseのアイコン変更、
#                   gridEditor起動時にpolyMeshの場所検索をfieldDirから探す（第1優先）
#          04/18    cell(face)ZoneNamesFの高速検索に変更
#          04/30    createNewCaseをnotebookに変更
#                   mesh入れ替えで同じmeshの場合、internalFieldを保存する（ver1.41）
#          05/01    unv2gmshToFoam変換にてzone名を直に書き出しするように変更
#          05/04    gridEditorの同時複数起動。HelyxOS-1.0.1起動時のdir設定のバグ修正
#          05/11    gridEditor起動時のboundaryの場所検索方法を変更
#                   gridEditorのpatch名をsortして表示。（ver1.42）
#          05/12    createNewCase:tutorialsのcase表示もれがあったのを修正
#          05/13    timeFolderの編集をfirstTime,latestTime,startTimeの3種で決定。
#          05/20    multiReginをOF2.2.0に対応させる
#          05/21    multiRegionのchangeDictにUを追加
#          05/24    snappyHexのOF2.2.0対応としてHelyxOSのfeatureEdge作成を修正
#          06/09    gridEditor:patch名の「"xxx.*"」に対応した
#          06/10    gridEditor:{}付きのcellデータにｲﾝﾃﾞﾝﾄ追加。
#                   boundaryField内にpatchﾃﾞｰﾀ以外(include等)がある場合も読込・保存可能
#          06/22    setMultiRegion:region名追加・変更・削除ボタンを追加
#          06/30    createBaffles, setFieldsをOF-2.2.用に修正
#          07/07    gridEditor:textEditorによる編集を追加
#          07/13    topoSetEditor:-timeｵﾌﾟｼｮﾝを削除。sourceMesh、resultMeshを表示
#          07/20    runHelyxOSDialog.getHelyxosData修正に伴う変更
#          07/27    createAndChangeCaseDialogのmesh入れ替えの表示を修正
#          08/01    rootDir,solveCaseDirが存在しなかった場合、
#                   rootDir:homeDir、solveCaseDir:TreeFoamPathに設定する様変更
#          08/11    gridEditor:patch名sort時、saveFlagチェック追加
#          08/18    timeFolderの表示方法変更（latest, start, firstTimeを追加)
#                   timeFolderの位置変更、menuButtonからtoolBarに変更（ver1.50）
#          08/21    createAndChangeCaseDialogを修正（バグ修正）
#          09/06    runHelyxosDialogにparaFoam起動ボタン追加
#          09/13    gridEditorのgzip、binaryﾌｧｲﾙへの対応(fieldのみ)、書込みの高速化
#                   gridEditorのcellEditorバグ修正（2回目の編集できない）
#          09/15    field編集でbinaryの編集を可能にした
#          09/18    gridEditorの表示行数、nonuniform読込行数変更dialog追加
#          09/24    gridEditor:fieldの読込方法をasciiとdataに分離して読み込む
#          09/25    binaryMeshの読込書込に対応。
#          09/29    binary、gzipに完全対応（ver1.51）
#          10/04    deleteFolder時、selctCaseDirが親になっていたのを子に変更
#          10/06    多言語用に書き換え（ver1.52）
#          10/09    言語変更をmenuに追加。ｲﾝｽﾄｰﾙ後の初回起動時、$LANGの設定に合わせる
#          10/12    多言語対応（ver1.53）
#          11/02    runHlyxOS:stlのチェック、csvからsnappyDictを作り出す追加
#          11/13    fileOperationInRegion:表示を一部treeに変更（ver1.54）
#          12/02    setFieldsDictをgrid上で編集できる様に修正（ver1.55）
#          12/08    meshOperationDialogにcsvによるmesh作成を追加（ver1.56）
#          12/09    gridEditor:clipBoardをsystemのclipBoardに変更
#          12/14    TreeFoamに停止方法を追加（ver2.00）
#          12/21    TreeFoamnにlogWindow、BCPnを追加（ver2.10）
#          12/27    getFoamContents:バグ修正
#       14/01/11    getFoamContents:バグ修正
#          01/18    getSelectionTimeを修正（startTimeが実在しない場合、起動できず）
#                   startTing画面が残る場合があるので、消す様に設定（ver2.11)
#          01/19    getSelectionTimeを再修正
#          02/04    csvによるsnappyでﾒｯｼｭ作成する時、csv作成後、csv編集する様に修正
#                   modelSize取得時、patch座標→全stl座標で取得する様に修正
#          02/08    gridEditorバグ修正。
#          02/22    caseCopy時、log、bak、"~"ファイルをコピーしない様に修正 
#          03/01    case作成時、currentCaseにtimeフォルダが存在しないとｴﾗｰ発生を修正
#          03/02    起動時のOFversionの取得方法を修正
#          03/06    createSetFieldsDictDialogを修正
#          03/18    snappyHexMeshDialog(220)を修正、editBoundaryConditionsを修正
#                   runHelyxOSDialog(220)を修正、createBlockAndSnappyDictを修正
#          04/07    fileOperationInRegion、selectFieldsForEdit、selectFolderFiles
#                   のfileOpen方法を修正（asciiの場合は、直接openする）
#          04/12    snappyHexMeshDialog、snappyHexMeshDialog220でtrisurfaceﾌｫﾙﾀﾞが
#                   無かった場合ｴﾗｰ発生を修正
#                   createBafflesDialog220:Dictファイルを自動生成（ver2.12）
#          04/13    getFoamContents:「**.**」のfield名があった場合ｴﾗｰ発生を修正
#                   環境変数:LANG、LANGUAGEとも言語を設定。(ubuntu 13.10 以降要)
#          04/14    setDataInFields, createBafflesDialogのbutton形状変更
#          05/01    foldersCasesPasteの後、reloadItemsを追加（pasteされたfolderを表示）
#                   fileOperationInRegionDialog:popupMenu、toolTipを追加
#          05/03    meshOperationDialog:領域分割を2.3.0に対応
#          05/12    editBoundaryConditionに#include、inGroupsを追加（ver2.13）
#          05/14    gaugeDDialogを微修正、HELYXOS-2.0に対応。
#          05/18    runHelixosDialog、runHelyxosDialog220を微修正
#          06/01    runHelixosDialog、runHelyxosDialog220にtimeFolder追加
#          06/04    snappyHexMeshDialog、editBounadryConditionsDialogに
#                   「全ての空patch削除」ﾒﾆｭｰを追加
#          06/07    splitMeshCellZones、setMultiRegionDialogを修正
#          06/11    gtkをimportして、systemのclipBoardの使用可能に修正。(ver2.20)
#                   treeFoamの起動、終了をgtk形式に変更。ﾒﾆｭｰのｼｮｰﾄｶｯﾄ変更。
#          06/21    fileOperationInregionを修正
#          07/05    paraFoam起動方法を修正(ver2.21)
#          07/10    topoSetEditor起動方法を修正
#          07/12    createBlockAndSnappy:faceを追加。
#                   snappyHexMesh, runHelyxOS:バグ修正
#                   configTreeFoamを修正（segmentation faultが発生した為）（ver2.22）
#                   runParaFoamDirを修正（　　↑　　）
#          07/15    changeConfigTreeFoam:solveCaseFixを保存
#          07/18    createBlockSnappyDictを修正
#          07/27    multiRegionの分割方法を修正、paraFoam起動方法修正
#          08/03    FOAM端末の画面サイズ変更、editBoundaryConditionDialog修正
#          08/23    editBoundaryConditionDialog:変数定義行を追加（ver2.23）
#          08/25    getfoamContents:文字列取得時のバグ修正
#          08/26    getFoamContents:binary保存時、unicodeｴﾗｰ発生を修正
#          09/02    createAndChangeCaseDialog:バグ修正（meshｺﾋﾟｰ時、ｴﾗｰ発生する）
#          09/05    treeFoam.runEditMesh:バグ修正（OF環境で起動していた。）
#                   createLayerDialogを追加
#          10/12    createBCsForMultiRegionDialog:追加（ver2.24）
#          10/25    meshOperetionDialog, splitMeshCellZones:領域分割時fieldも配布
#                   する様に修正。
#          10/26    gridEditor:階層型変数「$:」定義のﾈｽﾃｨﾝｸﾞ（最大10回）に対応。
#          11/04    setDataInFieldsDialog:mapFields追加
#          11/09    createBCsForMultiRegionDialog:region間境界面で自由waildCardを追加
#                   selectFolderFilesDialog:ﾀﾞﾌﾞﾙｸﾘｯｸでdirectory移動やfileOpenを追加
#                   createAndChangeCaseDialog:copyMeshとcurrMeshのチェックを追加
#          11/11    gridEditor, creaeBCsForMultiRegionDialogのバグ修正
#                   gaugeDDialog:load時の「$:」変数解釈のバグ修正
#          11/14    createBCsForMultiRegionDialog:バグ修正
#          11/15    setMultiRegionDialog:ボタン2ヶ追加
#          11/24    fileOperationInRegionDialog:修正
#          11/29    fileOperationInRegionDialog:項目の選択表示方法を修正
#          11/30    runParallelDialog:処理方法を修正
#          12/08    runParallel, setFoamContents、makeRunTopoSet、createBaffles:修正
#          12/13    runParallelDialog:decomposeParを修正
#          12/17    createBaffleDialog:subCaseにcaseDir直下のfileのコピーを追加
#          12/23    createAndChangeCase, setMultiRegion, snappyHexMesh:バグ修正
#          12/25    meshOperationDialog:バグ修正
#          12/27    editStlFilesDialog:stlFile結合ﾎﾞﾀﾝ追加
#       15/01/05    runHelyxosDialog220:ﾊﾞｸﾞ修正
#          01/10    editStlFilesDialog:バグ修正
#          01/13    editStlFilesDialog:ボタン、toolTipを追加
#          01/14    caseCopy時、".png", ".jpg", ".obj"をｺﾋﾟｰしない様に修正
#          01/19    createSetFieldsDialog:バグ修正
#          01/25    createLayersDDialog:layerがpatch毎に設定できる様に修正
#          02/02    createSetFieldsDictDialog:バグ修正
#          02/05    casesCopy, deleteResultFoldersの作動を変更（ver2.25）
#          02/07    meshOperationDialog:領域分割時のfile配布方法を修正
#          02/08    fileOperationInRegionDialog:region選択時、fileListを再表示
#          02/09    fileOperationInRegionDialog:ﾎﾟｯﾌﾟｱｯﾌﾟﾒﾆｭｰを修正
#          02/12    createAndChangeCaseDialog:ﾊﾞｸﾞ修正
#          02/15    iniCase追加、deleteResultFoldersの作動を元に戻す、caseコピー削除
#                   case貼付けをsystemClipBoardからcaseを取得
#                   selReload：currentDirectoryを設定（os.getcwd()で取得できる様に）
#          02/16    setDataInFieldsDialog:バグ修正
#          02/18    setDataInFieldsDialog:mapFieldsの設定を保存する様に修正
#          02/23    fileOperationInRegionDialog:バグ修正
#          02/24    editBoundaryConditionsDialog:バグ修正、余分な行を削除
#          03/02    addDeleteRegion, editBoundaryConditions, fileOperationInRegion,
#                   setMultiRegionDialogを修正
#          03/08    openGridEditorDialog, runGridEditorを修正
#          03/18    runParaFoamを修正
#          03/29    unv2abaqus.py, abaqus2fistr.py, unv2fistr.pyを追加
#          06/25    ubuntu15.04に対応。wxPythonが2.8→3.0にバージョンアップされ大幅修正
#                   treeCtrl内のtoolTipは削除、gtkを削除（copy&pasteを外に出す）
#                   (ver 2.30)
#          06/29    toolTipを再表示させる。
#          06/30    createBaffles:空patch不要、cyclic,mappedPatchが自動作成できる様修正
#          07/02    topoSetEditor:resultTypeに「sets」と「zones」を追加（ver 2.31）
#          07/05    gridEditorの起動方法を修正
#          07/07    runParallel:decomposeParDict内のsetPreserveを追加
#          07/10    editBoundaryConditions:バグ修正
#          07/13    clipBoardをTreeFoam/→TreeFoam/dataに移動
#          07/18    $TreeFoamUserPathを作成。version記録方法を修正
#          07/23    changeConfigTreeFoam:修正
#          07/26    changeConfigTreeFoam:ボタンを追加
#          07/27    foldersPaste,casesPaste:unicodeでpasteに変更
#          08/02    readConf:selCaseDirが存在しない場合、rootDirに設定
#          08/07    initializeTreeFoam:TreeFoamのversionの記録方法を変更
#          08/09      ↑（再度変更）
#          09/27    OnPopupItemSelected:CAD,SalomeMecaの起動方法変更（バグ修正）
#          10/10    combo_boxの定義文修正。changeTimeFolder, changeStopAtを修正
#                   comboBox上でstartTiem、endTimeが修正できなかったのを修正
#          11/27    initializeTreeFoam:バグ修正。隠しファイルがい場合の言語の設定時エラー
#       16/03/02    sshfsDirを追加 (ver 2.37)
#          03/07    initializeTreeFoam:sshfs_dataファイル有無チェックを追加
#          05/04    runFoamTermDir:マウントfolderの場合の処理を変更
#          05/30    initializeTreeFoam:sshfsDirの読み取りを修正
#                   pasteScpCompTransfer:サーバ内同士のコピーを追加
#          06/01    pasteScpCompTransfer:コピー先が同じ場合は、file名に
#                   「_copy」が追加されるよう修正。
#          07/28    windowのサイズをwxとTreeFoamのバージョンのセットで変更する様に修正
#
#
#-----------code生成後の修正項目----------------
#
#   ・アイコンのDirを書き直す（絶対path→相対path[./icons/***.png]）
#   ・combo_boxの定義文の末尾に「|wx.TE_PROCESS_ENTER」を追加する。
#       self.combo_box_1 = wx.ComboBox(self.panel_2, wx.ID_ANY, choices=[_("startTime"), _("latestTime")], style=wx.CB_DROPDOWN|wx.TE_PROCESS_ENTER)
#
#   ・2段めのtollbarを設定する場合
#   　2段めのtoolbarを「self.frame_1.toolbar1」で定義
#     self.SetToolBar(self.frame_1_toolbar)をコメントアウト
#     self.frame_1_toolbar, self.frame_1_toolbar1を「sizer_1」に追加
#
#


# generated by wxGlade 0.6.3 on Sun Feb 20 15:26:34 2011


#start画面出力用fileを定義
import os
#startFile = open(os.environ["TreeFoamPath"] + "/temp/startingInput.txt", "a")
startFile = open(os.environ["TreeFoamUserPath"] + "/temp/startingInput.txt", "a")
startFile.write("importing standerd module...\n")

import wx
import wx.gizmos
import glob
import codecs
import shutil
import string
import gio
import sys

startFile.write("importing TreeFoam module...\n")
import pyTreeFoam
import getFoamContents
import setFoamContents
import gaugeDDialog
#import changeConfigTreeFoamDialog
import inputTextDDialog
from runHelyxosDialog import getHelyxosData

#clipBoardを使うためにimport
#startFile.write("importing gtk...\n")
#import pygtk
#pygtk.require('2.0')
#import gtk
#import urllib


startFile.write("loading treefoam...\n") 

version = "2.38-160908"             #TreeFoamのバージョン
foamTermSize = "110x24"             #Foam端末のサイズ
treeFoamPath = ""                   #TreeFoamのパス
OFversionFix = ""                   #OpenFOAMのバージョン
rootDirFix = ""
selCaseDirFix = ""
solveCaseFix = ""
paraFoamFix = ""
salomeMecaFix = ""
envOpenFOAMFix = ""
cadFix = ""
helyxosFix = ""
languageFix = ""
sshfsDir = ""
gridNo = []                 #gridのNo、Dirを一時保存
nTreeFoam = ""              #TreeFoamの起動数
treeSize = (800, 500)       #windowSize
fontSize = 10               #font size
colWidth = [300,            #Tree width
            200,            #solver width
            40,             #BCPn width
            40,             #nR width
            60,             #st width
            60]             #ed width
splitWidth = 300            #windowの分割
frameShow = "no"            #frameの表示完了フラグ

rootDir = ""
selCaseDir = ""
selectTreeDir = ""
treeData = []
selCase = []
configFile = "configTreeFoam"
editName = ""
childrenList = []
timeFolders = ["0","1"]
clipBoard = ""
displayFieldsFile = ".displayField"     #表示させるfield名を保存するﾌｧｲﾙ名
editor = "gedit --new-window --wait"    #使用するeditor（デフォルトの設定）
machinesFile = "machines"               #並列計算させる時のnode名記述ﾌｧｲﾙ
folderMsg = "no"                        #folderErrorMsgを禁止
toolTipText = ""                        #tree_ctrlのtoolTip表示内容
winSizeFile = "data/winSize"            #window size の保存場所
nRunningTreeFoam = "data/nRunningTreeFoam"  #TreeFoamnの起動No保存ファイルの場所
sysFontColour = "#4c4c4c"               #systemFontの色（グレー）
firstTime = ""
startTime = ""
latestTime = ""
startFrom = ""
stopAt = ""
endTime = ""
#sysClipboard = gtk.clipboard_get()      #systemClipBoard設定


changeConfigTreeFoamID = wx.NewId()
changeRootID = wx.NewId()
reloadID = wx.NewId()
exitID = wx.NewId()
usageID = wx.NewId()
versionID = wx.NewId()
newCaseID = wx.NewId()
setCurrCaseID = wx.NewId()
gridEditorID = wx.NewId()
editFieldID = wx.NewId()
editPropertiesID = wx.NewId()
editDictID = wx.NewId()
editMeshID = wx.NewId()
renameCaseID = wx.NewId()
runSolverID = wx.NewId()
plotWatcherID = wx.NewId()
parallelSolverID = wx.NewId()
runFoamTermID = wx.NewId()
runParaFoamID = wx.NewId()
runFoamViewerID = wx.NewId()
runSalomeID = wx.NewId()
runCADID = wx.NewId()
dataSetClearID = wx.NewId()
FolderOpenID = wx.NewId()
copyFolderID = wx.NewId()
pasteFolderID = wx.NewId()
addFolderID = wx.NewId()
delFolderID = wx.NewId()
caseCopyID = wx.NewId()
casePasteID = wx.NewId()
topoSetID = wx.NewId()
helyxosID = wx.NewId()
multiRegID = wx.NewId()

toolChangeConfigID = wx.NewId()
toolChangeRootID = wx.NewId()
toolReloadID = wx.NewId()
toolExitID = wx.NewId()
toolNewCaseID = wx.NewId()
toolEditMeshID = wx.NewId()
toolHelyxosID = wx.NewId()
toolGridEditorID = wx.NewId()
toolEditFieldID = wx.NewId()
toolIniCaseID = wx.NewId()
toolDataSetClearID = wx.NewId()
toolEditPropertiesID = wx.NewId()
toolEditDictID = wx.NewId()
toolRunSolverID = wx.NewId()
toolPlotWatcherID = wx.NewId()
toolRunCADID = wx.NewId()
toolRunFoamTermID = wx.NewId()
toolRunSalomeID = wx.NewId()
toolActiveCaseID = wx.NewId()
toolTopoSetEditorID = wx.NewId()
toolSetMultiRegionID = wx.NewId()
toolDeleteResultID = wx.NewId()
toolParallelID = wx.NewId()
toolRunParaFoamID = wx.NewId()

# begin wxGlade: extracode
# end wxGlade


class MyFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        global rootDir, selCaseDir, envOpenFOAMFix, fontSize
        # begin wxGlade: MyFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        
        # Menu Bar
        self.frame_1_menubar = wx.MenuBar()
        self.menuFile = wx.Menu()
        self.menuChangeConfigTreeFoam = wx.MenuItem(self.menuFile, changeConfigTreeFoamID, _(u"configTreeFoamの変更(&T)"), _(u"TreeFoamの設定を変更します"), wx.ITEM_NORMAL)
        self.menuFile.AppendItem(self.menuChangeConfigTreeFoam)
        self.menuChangeRoot = wx.MenuItem(self.menuFile, changeRootID, _(u"rootの変更(&C)"), _(u"rootDirectoryの変更"), wx.ITEM_NORMAL)
        self.menuFile.AppendItem(self.menuChangeRoot)
        self.menuReload = wx.MenuItem(self.menuFile, reloadID, _(u"再読み込み(&R)"), _(u"treeDataを再読み込みします"), wx.ITEM_NORMAL)
        self.menuFile.AppendItem(self.menuReload)
        self.menuExit = wx.MenuItem(self.menuFile, exitID, _(u"閉じる(&Q)"), "", wx.ITEM_NORMAL)
        self.menuFile.AppendItem(self.menuExit)
        self.frame_1_menubar.Append(self.menuFile, _(u"ファイル(&F)"))
        self.menuCreateCase = wx.Menu()
        self.menuSetCurrCase = wx.MenuItem(self.menuCreateCase, setCurrCaseID, _(u"解析caseとして設定(&S)"), _(u"選択しているcaseを解析Caseとして設定します"), wx.ITEM_NORMAL)
        self.menuCreateCase.AppendItem(self.menuSetCurrCase)
        self.menuNewCase = wx.MenuItem(self.menuCreateCase, newCaseID, _(u"新しいcase作成(&N)"), _(u"新しいcaseの作成、caseを変更（solver、meshの入れ替え）。"), wx.ITEM_NORMAL)
        self.menuCreateCase.AppendItem(self.menuNewCase)
        self.menuEditMesh = wx.MenuItem(self.menuCreateCase, editMeshID, _(u"Mesh編集(&M)"), _(u"解析Caseのmeshを編集（変換、scale変更等）します"), wx.ITEM_NORMAL)
        self.menuCreateCase.AppendItem(self.menuEditMesh)
        self.menuTopoSet = wx.MenuItem(self.menuCreateCase, topoSetID, _(u"topoSetEditor起動(&T)"), _(u"topoSetEditorを起動して、meshを抽出"), wx.ITEM_NORMAL)
        self.menuCreateCase.AppendItem(self.menuTopoSet)
        self.menuSetMultiRegion = wx.MenuItem(self.menuCreateCase, multiRegID, _(u"multuRegionの設定(&R)"), _(u"multiRegionの設定とregion内のfile操作"), wx.ITEM_NORMAL)
        self.menuCreateCase.AppendItem(self.menuSetMultiRegion)
        self.menuHelyxos = wx.MenuItem(self.menuCreateCase, helyxosID, _(u"helyxOSによる編集(&H)"), _(u"helyxOSによるmesh作成"), wx.ITEM_NORMAL)
        self.menuCreateCase.AppendItem(self.menuHelyxos)
        self.frame_1_menubar.Append(self.menuCreateCase, _(u"case作成変更(&M)"))
        self.menuEdit = wx.Menu()
        self.menuFolderOpen = wx.MenuItem(self.menuEdit, FolderOpenID, _(u"開く(&O)"), _(u"解析Caseを開く"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuFolderOpen)
        self.menuGridEditor = wx.MenuItem(self.menuEdit, gridEditorID, _(u"gridEditor起動(&G)"), _(u"gridEditoを起動します"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuGridEditor)
        self.menuEditField = wx.MenuItem(self.menuEdit, editFieldID, _(u"Field編集(&F)"), _(u"解析CaseのFieldを編集します"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuEditField)
        self.menuEditProperties = wx.MenuItem(self.menuEdit, editPropertiesID, _(u"Properties編集(&P)"), _(u"解析Caseのpropertiesを編集します"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuEditProperties)
        self.menuEditDict = wx.MenuItem(self.menuEdit, editDictID, _(u"Dictionary編集(&D)"), _(u"解析CaseのDictを編集します"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuEditDict)
        self.menuDataSetClear = wx.MenuItem(self.menuEdit, dataSetClearID, _(u"FieldDataSet又はclear(&S)"), _(u"Fieldにデータセット、又はクリア"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuDataSetClear)
        self.menuEdit.AppendSeparator()
        self.menuCopyFolder = wx.MenuItem(self.menuEdit, copyFolderID, _(u"コピー(&C)\tCtrl+C"), _(u"フォルダをコピーします"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuCopyFolder)
        self.menuPasteFolder = wx.MenuItem(self.menuEdit, pasteFolderID, _(u"貼り付け(&P)\tCtrl+V"), _(u"フォルダの貼付け"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuPasteFolder)
        self.menuCasePaste = wx.MenuItem(self.menuEdit, casePasteID, _(u"caseの貼り付け(&B)\tCtrl+B"), _(u"caseの貼り付け"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuCasePaste)
        self.menuEdit.AppendSeparator()
        self.menuRenameCase = wx.MenuItem(self.menuEdit, renameCaseID, _(u"フォルダ名変更(&R)"), _(u"解析Caseの名称を変更します"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuRenameCase)
        self.menuAddFolder = wx.MenuItem(self.menuEdit, addFolderID, _(u"新しいフォルダ追加(&N)"), _(u"新しいフォルダを追加します"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuAddFolder)
        self.menuDelFolder = wx.MenuItem(self.menuEdit, delFolderID, _(u"フォルダ削除(&E)"), _(u"folderを削除します"), wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuDelFolder)
        self.frame_1_menubar.Append(self.menuEdit, _(u"編集(&E)"))
        self.menuSolve = wx.Menu()
        self.menuRunSolver = wx.MenuItem(self.menuSolve, runSolverID, _(u"計算開始(&G)"), _(u"activeCaseの計算を開始します"), wx.ITEM_NORMAL)
        self.menuSolve.AppendItem(self.menuRunSolver)
        self.menuPlotWatcher = wx.MenuItem(self.menuSolve, plotWatcherID, _(u"plotWatcher起動(&W)"), _(u"plotWatcherを起動します。"), wx.ITEM_NORMAL)
        self.menuSolve.AppendItem(self.menuPlotWatcher)
        self.menuParallelSolver = wx.MenuItem(self.menuSolve, parallelSolverID, _(u"並列計算(&P)"), _(u"並列計算に関する設定を行います"), wx.ITEM_NORMAL)
        self.menuSolve.AppendItem(self.menuParallelSolver)
        self.frame_1_menubar.Append(self.menuSolve, _(u"計算(&C)"))
        self.menuTool = wx.Menu()
        self.menuRunCAD = wx.MenuItem(self.menuTool, runCADID, _(u"CADの起動(&C)"), _(u"CADを起動します"), wx.ITEM_NORMAL)
        self.menuTool.AppendItem(self.menuRunCAD)
        self.menuRunFoamTerm = wx.MenuItem(self.menuTool, runFoamTermID, _(u"FOAM端末の起動(&T)"), _(u"FOAM端末を起動します"), wx.ITEM_NORMAL)
        self.menuTool.AppendItem(self.menuRunFoamTerm)
        self.menuRunParaFoam = wx.MenuItem(self.menuTool, runParaFoamID, _(u"paraFoamの起動(&P)"), _(u"paraFoamを起動します"), wx.ITEM_NORMAL)
        self.menuTool.AppendItem(self.menuRunParaFoam)
        self.menuRunFoamViewer = wx.MenuItem(self.menuTool, runFoamViewerID, _(u"viewerの起動(&V)"), _(u"viewerを起動します"), wx.ITEM_NORMAL)
        self.menuTool.AppendItem(self.menuRunFoamViewer)
        self.menuRunSalome = wx.MenuItem(self.menuTool, runSalomeID, _(u"SalomeMecaの起動(&S)"), _(u"SalomeMecaを起動します"), wx.ITEM_NORMAL)
        self.menuTool.AppendItem(self.menuRunSalome)
        self.frame_1_menubar.Append(self.menuTool, _(u"ツール(&T)"))
        self.menuHelp = wx.Menu()
        self.menuUsage = wx.MenuItem(self.menuHelp, usageID, _(u"使い方(&U)"), _(u"使い方の表示"), wx.ITEM_NORMAL)
        self.menuHelp.AppendItem(self.menuUsage)
        self.menuVersion = wx.MenuItem(self.menuHelp, versionID, _(u"バージョン表示(&V)"), "", wx.ITEM_NORMAL)
        self.menuHelp.AppendItem(self.menuVersion)
        self.frame_1_menubar.Append(self.menuHelp, _(u"ヘルプ(&H)"))
        self.SetMenuBar(self.frame_1_menubar)
        # Menu Bar end
        self.frame_1_statusbar = self.CreateStatusBar(1, wx.ST_SIZEGRIP)
        
        # Tool Bar
        self.frame_1_toolbar = wx.ToolBar(self, -1, style=wx.TB_HORIZONTAL | wx.TB_DOCKABLE | wx.TB_3DBUTTONS)
        self.SetToolBar(self.frame_1_toolbar)
        self.frame_1_toolbar.AddLabelTool(toolChangeConfigID, _("config"), wx.Bitmap("./icons/preferences-system.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"configTreeFoamの設定"), _(u"configTreeFoamの設定を変更する"))
        self.frame_1_toolbar.AddLabelTool(toolChangeRootID, _("root"), wx.Bitmap("./icons/changeRoot.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"rootDirの変更"), _(u"treeの最上位（rootDir）を変更する"))
        self.frame_1_toolbar.AddLabelTool(toolReloadID, _("reload"), wx.Bitmap("./icons/reload.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"dirの再読み込み"), _(u"tree構造（dir）を再読み込みする"))
        self.frame_1_toolbar.AddLabelTool(toolExitID, _("exit"), wx.Bitmap("./icons/exit.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"閉じる"), _(u"TreeFoamの終了"))
        self.frame_1_toolbar.AddSeparator()
        self.frame_1_toolbar.AddLabelTool(toolActiveCaseID, _("active"), wx.Bitmap("./icons/setCase.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"選択したフォルダを解析caseに設定"), _(u"選択しているフォルダを解析caseに設定する"))
        self.frame_1_toolbar.AddLabelTool(toolNewCaseID, _("new"), wx.Bitmap("./icons/createChange24.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"新規にcaseを作成、又はsolverやmeshを入れ替え"), _(u"新規にcaseを作成したり、solverやmeshを入れ替える"))
        self.frame_1_toolbar.AddLabelTool(toolEditMeshID, _("mesh"), wx.Bitmap("./icons/editMesh.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"meshの編集"), _(u"meshを編集する"))
        self.frame_1_toolbar.AddLabelTool(toolTopoSetEditorID, _("topo"), wx.Bitmap("./icons/topoEditMesh.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"meshの抽出（topoSetEditorの起動）"), _(u"topoSetEditorを起動してmeshを抽出する"))
        self.frame_1_toolbar.AddLabelTool(toolSetMultiRegionID, _("multi"), wx.Bitmap("./icons/multiRegion.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"multiRegion内のfile操作"), _(u"multiRegionCase内のfileを操作する"))
        self.frame_1_toolbar.AddLabelTool(toolHelyxosID, _("helyx"), wx.Bitmap("./icons/helyxos-F2.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"HelyxOSによる操作"), _(u"HelyxOSによるmesh作成、solver実行"))
        self.frame_1_toolbar.AddSeparator()
        self.frame_1_toolbar.AddLabelTool(toolGridEditorID, _("grid"), wx.Bitmap("./icons/gridEditor.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"gridEditor起動"), _(u"gridEditorを起動し、boundaryを編集"))
        self.frame_1_toolbar.AddLabelTool(toolEditFieldID, _("Field"), wx.Bitmap("./icons/editFields.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"fieldの編集"), _(u"fieldをeditorで編集する"))
        self.frame_1_toolbar.AddLabelTool(toolDataSetClearID, _("data"), wx.Bitmap("./icons/dataSetClear.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"Fieldにデータをセット、又はクリア"), _(u"internalFieldにデータをセットしたり、クリアする"))
        self.frame_1_toolbar.AddLabelTool(toolEditPropertiesID, _("Proper"), wx.Bitmap("./icons/editProperties-cons.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"Propertiesの編集"), _(u"Propertiesを編集する"))
        self.frame_1_toolbar.AddLabelTool(toolEditDictID, _("Dict"), wx.Bitmap("./icons/editDict-sys.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"Dict（system）の編集"), _(u"Dict（system）を編集する"))
        self.frame_1_toolbar.AddSeparator()
        self.frame_1_toolbar.AddLabelTool(toolIniCaseID, _("iniCase"), wx.Bitmap("./icons/iniCase-4.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"計算結果を削除して、caseを初期化します"), _(u"計算結果を削除して、caseを初期化します"))
        self.frame_1_toolbar.AddLabelTool(toolDeleteResultID, _("delete"), wx.Bitmap("./icons/deleteResult.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"計算結果のみクリア"), _(u"計算結果のみをクリアする"))
        self.frame_1_toolbar.AddLabelTool(toolRunSolverID, _("run"), wx.Bitmap("./icons/runSolver.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"solverを起動"), _(u"solverを起動する"))
        self.frame_1_toolbar.AddLabelTool(toolPlotWatcherID, _("plot"), wx.Bitmap("./icons/plotWatcher.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"plotWatcherの起動"), _(u"plotWatcherを起動する"))
        self.frame_1_toolbar.AddLabelTool(toolParallelID, _("para"), wx.Bitmap("./icons/parallel.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"並列処理"), _(u"並列処理を実施する"))
        self.frame_1_toolbar.AddSeparator()
        self.frame_1_toolbar.AddLabelTool(toolRunCADID, _("CAD"), wx.Bitmap("./icons/runCAD.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"CADの起動"), _(u"CADを起動する"))
        self.frame_1_toolbar.AddLabelTool(toolRunFoamTermID, _("Foam"), wx.Bitmap("./icons/runFoamTerm.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"FOAM端末の起動"), _(u"FOAM端末を起動する"))
        self.frame_1_toolbar.AddLabelTool(toolRunParaFoamID, _("view"), wx.Bitmap("./icons/pqAppIcon22.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"paraFoamの起動"), _(u"paraFoamを起動する"))
        self.frame_1_toolbar.AddLabelTool(toolRunSalomeID, _("Salome"), wx.Bitmap("./icons/salome_default.png", wx.BITMAP_TYPE_ANY), wx.NullBitmap, wx.ITEM_NORMAL, _(u"SalomeMecaの起動"), _(u"SalomeMecaを起動する"))
        # Tool Bar end
        self.window_1 = wx.SplitterWindow(self, wx.ID_ANY, style=wx.SP_3D | wx.SP_BORDER)
        self.window_1_pane_1 = wx.Panel(self.window_1, wx.ID_ANY)
        self.static_line_7 = wx.StaticLine(self.window_1_pane_1, wx.ID_ANY)
        self.panel_4 = wx.Panel(self.window_1_pane_1, wx.ID_ANY)
        self.label_1 = wx.StaticText(self.panel_4, wx.ID_ANY, _("case directory:"))
        self.panel_3 = wx.Panel(self.window_1_pane_1, wx.ID_ANY)
        self.label_3 = wx.StaticText(self.panel_3, wx.ID_ANY, _("label_3"))
        self.label_11 = wx.StaticText(self.panel_3, wx.ID_ANY, _(u"OpenFoam環境:"))
        self.label_6 = wx.StaticText(self.panel_3, wx.ID_ANY, _("label_6"))
        self.panel_6 = wx.Panel(self.window_1_pane_1, wx.ID_ANY)
        self.label_2 = wx.StaticText(self.panel_6, wx.ID_ANY, _(u"現在の解析case名:"), style=wx.ALIGN_RIGHT)
        self.panel_1 = wx.Panel(self.window_1_pane_1, wx.ID_ANY)
        self.bitmap_2 = wx.StaticBitmap(self.panel_1, wx.ID_ANY, wx.Bitmap("./icons/x-office-document_check16.png", wx.BITMAP_TYPE_ANY))
        self.label_5 = wx.StaticText(self.panel_1, wx.ID_ANY, _("label_5"))
        self.label_8 = wx.StaticText(self.panel_1, wx.ID_ANY, _("startFrom"))
        self.label_9 = wx.StaticText(self.panel_1, wx.ID_ANY, _("stopAt"))
        self.label_10 = wx.StaticText(self.panel_1, wx.ID_ANY, _("controlDict"))
        self.panel_5 = wx.Panel(self.window_1_pane_1, wx.ID_ANY)
        self.label_4 = wx.StaticText(self.panel_5, wx.ID_ANY, _("solver:"), style=wx.ALIGN_RIGHT)
        self.panel_2 = wx.Panel(self.window_1_pane_1, wx.ID_ANY)
        self.bitmap_1 = wx.StaticBitmap(self.panel_2, wx.ID_ANY, wx.Bitmap("./icons/folder-documents16.png", wx.BITMAP_TYPE_ANY))
        self.label_7 = wx.StaticText(self.panel_2, wx.ID_ANY, _("label_7"))
        #self.combo_box_1 = wx.ComboBox(self.panel_2, wx.ID_ANY, choices=[_("startTime"), _("latestTime")], style=wx.CB_DROPDOWN
        self.combo_box_1 = wx.ComboBox(self.panel_2, wx.ID_ANY, choices=[_("startTime"), _("latestTime")], style=wx.CB_DROPDOWN|wx.TE_PROCESS_ENTER)
        #self.combo_box_2 = wx.ComboBox(self.panel_2, wx.ID_ANY, choices=[], style=wx.CB_DROPDOWN)
        self.combo_box_2 = wx.ComboBox(self.panel_2, wx.ID_ANY, choices=[], style=wx.CB_DROPDOWN|wx.TE_PROCESS_ENTER)
        self.button_1 = wx.Button(self.panel_2, wx.ID_ANY, _(u"編集"))
        #self.tree_ctrl_1 = wx.TreeCtrl(self.window_1_pane_1, wx.ID_ANY, style=wx.TR_HAS_BUTTONS | wx.TR_NO_LINES | wx.TR_MULTIPLE | wx.TR_MULTIPLE | wx.TR_DEFAULT_STYLE | wx.SUNKEN_BORDER)

        self.window_1_pane_2 = wx.Panel(self.window_1, wx.ID_ANY)
        self.label_12 = wx.StaticText(self.window_1_pane_2, wx.ID_ANY, _("log"))
        self.button_2 = wx.Button(self.window_1_pane_2, wx.ID_ANY, _("open"))
        self.label_13 = wx.StaticText(self.window_1_pane_2, wx.ID_ANY, _("label_13"))
        self.text_ctrl_1 = wx.TextCtrl(self.window_1_pane_2, wx.ID_ANY, "", style=wx.TE_MULTILINE | wx.TE_READONLY)

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_MENU, self.selChangeConfigTreeFoam, self.menuChangeConfigTreeFoam)
        self.Bind(wx.EVT_MENU, self.selChangeRoot, self.menuChangeRoot)
        self.Bind(wx.EVT_MENU, self.selReload, self.menuReload)
        self.Bind(wx.EVT_MENU, self.selExit, self.menuExit)
        self.Bind(wx.EVT_MENU, self.selSetCurrCase, self.menuSetCurrCase)
        self.Bind(wx.EVT_MENU, self.selNewCase, self.menuNewCase)
        self.Bind(wx.EVT_MENU, self.selEditMesh, self.menuEditMesh)
        self.Bind(wx.EVT_MENU, self.selRunTopoSetEditor, self.menuTopoSet)
        self.Bind(wx.EVT_MENU, self.selSetMultiRegion, self.menuSetMultiRegion)
        self.Bind(wx.EVT_MENU, self.selHelyxos, self.menuHelyxos)
        self.Bind(wx.EVT_MENU, self.selFolderOpen, self.menuFolderOpen)
        self.Bind(wx.EVT_MENU, self.selGridEditor, self.menuGridEditor)
        self.Bind(wx.EVT_MENU, self.selEditField, self.menuEditField)
        self.Bind(wx.EVT_MENU, self.selEditProperties, self.menuEditProperties)
        self.Bind(wx.EVT_MENU, self.selEditDict, self.menuEditDict)
        self.Bind(wx.EVT_MENU, self.selDataSetClear, self.menuDataSetClear)
        self.Bind(wx.EVT_MENU, self.selCopyFolder, self.menuCopyFolder)
        self.Bind(wx.EVT_MENU, self.selPasteFolder, self.menuPasteFolder)
        self.Bind(wx.EVT_MENU, self.selCasePaste, self.menuCasePaste)
        self.Bind(wx.EVT_MENU, self.selRenameCase, self.menuRenameCase)
        self.Bind(wx.EVT_MENU, self.selAddFolder, self.menuAddFolder)
        self.Bind(wx.EVT_MENU, self.selDeleteFolder, self.menuDelFolder)
        self.Bind(wx.EVT_MENU, self.selRunSolver, self.menuRunSolver)
        self.Bind(wx.EVT_MENU, self.selPlotWatcher, self.menuPlotWatcher)
        self.Bind(wx.EVT_MENU, self.selParallelSolver, self.menuParallelSolver)
        self.Bind(wx.EVT_MENU, self.selRunCAD, self.menuRunCAD)
        self.Bind(wx.EVT_MENU, self.selRunFoamTerm, self.menuRunFoamTerm)
        self.Bind(wx.EVT_MENU, self.selRunParaFoam, self.menuRunParaFoam)
        self.Bind(wx.EVT_MENU, self.selRunFoamViewer, self.menuRunFoamViewer)
        self.Bind(wx.EVT_MENU, self.selRunSalome, self.menuRunSalome)
        self.Bind(wx.EVT_MENU, self.selUsage, self.menuUsage)
        self.Bind(wx.EVT_MENU, self.selVersion, self.menuVersion)
        self.Bind(wx.EVT_TOOL, self.onChangeConfigTreeFoam, id=toolChangeConfigID)
        self.Bind(wx.EVT_TOOL, self.onChangeRoot, id=toolChangeRootID)
        self.Bind(wx.EVT_TOOL, self.onReload, id=toolReloadID)
        self.Bind(wx.EVT_TOOL, self.onExit, id=toolExitID)
        self.Bind(wx.EVT_TOOL, self.onActiveCase, id=toolActiveCaseID)
        self.Bind(wx.EVT_TOOL, self.onNewCase, id=toolNewCaseID)
        self.Bind(wx.EVT_TOOL, self.onEditMesh, id=toolEditMeshID)
        self.Bind(wx.EVT_TOOL, self.onTopoSetEditor, id=toolTopoSetEditorID)
        self.Bind(wx.EVT_TOOL, self.onSetMultiRegion, id=toolSetMultiRegionID)
        self.Bind(wx.EVT_TOOL, self.onHelyxos, id=toolHelyxosID)
        self.Bind(wx.EVT_TOOL, self.onGridEditor, id=toolGridEditorID)
        self.Bind(wx.EVT_TOOL, self.onEditField, id=toolEditFieldID)
        self.Bind(wx.EVT_TOOL, self.onDataSetClear, id=toolDataSetClearID)
        self.Bind(wx.EVT_TOOL, self.onEditProperties, id=toolEditPropertiesID)
        self.Bind(wx.EVT_TOOL, self.onEditDict, id=toolEditDictID)
        self.Bind(wx.EVT_TOOL, self.onIniCase, id=toolIniCaseID)
        self.Bind(wx.EVT_TOOL, self.onDeleteResult, id=toolDeleteResultID)
        self.Bind(wx.EVT_TOOL, self.onRunSolver, id=toolRunSolverID)
        self.Bind(wx.EVT_TOOL, self.onPlotWatcher, id=toolPlotWatcherID)
        self.Bind(wx.EVT_TOOL, self.onParallel, id=toolParallelID)
        self.Bind(wx.EVT_TOOL, self.onRunCAD, id=toolRunCADID)
        self.Bind(wx.EVT_TOOL, self.onRunFoamTerm, id=toolRunFoamTermID)
        self.Bind(wx.EVT_TOOL, self.onRunParaFoam, id=toolRunParaFoamID)
        self.Bind(wx.EVT_TOOL, self.onRunSalome, id=toolRunSalomeID)
        self.Bind(wx.EVT_TEXT_ENTER, self.onChangeTime, self.combo_box_1)
        self.Bind(wx.EVT_COMBOBOX, self.onChangeTime, self.combo_box_1)
        self.Bind(wx.EVT_TEXT_ENTER, self.onChangeStopAt, self.combo_box_2)
        self.Bind(wx.EVT_COMBOBOX, self.onChangeStopAt, self.combo_box_2)
        self.Bind(wx.EVT_BUTTON, self.onEditControlDict, self.button_1)
        self.Bind(wx.EVT_TREE_ITEM_ACTIVATED, self.onItemActivated, self.tree_ctrl_1)
        self.Bind(wx.EVT_TREE_ITEM_COLLAPSED, self.onItemCollapsed, self.tree_ctrl_1)
        self.Bind(wx.EVT_TREE_ITEM_EXPANDED, self.onItemExpanded, self.tree_ctrl_1)
        self.Bind(wx.EVT_BUTTON, self.onOpenLogFile, self.button_2)
        # end wxGlade

        self.Bind(wx.EVT_CLOSE, self.onCloseWindow)
        self.Bind(wx.EVT_TREE_SEL_CHANGED, self.onSelChanged, self.tree_ctrl_1)
        #self.Bind(wx.EVT_TREE_KEY_DOWN, self.onKeyEvent, self.tree_ctrl_1)
        #self.Bind(wx.EVT_LEFT_DCLICK, self.onCaseOpen, self.label_7)
        #self.Bind(wx.EVT_LEFT_DCLICK, self.onCaseOpen, self.tree_ctrl_1)

        #----------------panel内のlabel（caseName, solverName）
        item = self.tree_ctrl_1.GetSelection()
        self.changeSolveCase(item)

        #----------------PopupMenu-------------
        self.popupmenu = wx.Menu()
        i=0
        for text in self.setPopupMenuItems():
            if text == "-":
                self.popupmenu.AppendSeparator()
            else:
                mmi = wx.MenuItem(self.popupmenu, i, text)
                #mmi.SetBitmap(wx.Bitmap("./icons/gridEditor.png"))
                #item = self.popupmenu.Append(-1, text)
                item = self.popupmenu.AppendItem(mmi)
                self.Bind(wx.EVT_MENU, self.OnPopupItemSelected, item)
            i+=1
        self.Bind(wx.EVT_TREE_ITEM_RIGHT_CLICK, self.OnShowPopup, self.tree_ctrl_1)

        self.popupmenuSolver = wx.Menu()
        for text in self.setPopupMenuItemsSolver():
            if text == "-":
                self.popupmenuSolver.AppendSeparator()
            else:
                item = self.popupmenuSolver.Append(-1, text)
                self.Bind(wx.EVT_MENU, self.OnPopupItemSolverSelected, item)

        self.popupmenuResult = wx.Menu()
        for text in self.setPopupMenuItemsResult():
            if text == "-":
                self.popupmenuResult.AppendSeparator()
            else:
                item = self.popupmenuResult.Append(-1, text)
                self.Bind(wx.EVT_MENU, self.OnPopupItemResultSelected, item)

        self.popupmenuNotSolveCase = wx.Menu()
        for text in self.setPopupMenuItemsNotSolveCase():
            if text == "-":
                self.popupmenuNotSolveCase.AppendSeparator()
            else:
                item = self.popupmenuNotSolveCase.Append(-1, text)
                self.Bind(wx.EVT_MENU, self.OnPopupItemNotSolveCaseSelected, item)

        #---------backgroundColourを設定-------------
        self.setBackgroundColour()

        #---------TreeCtrlのtoolTip表示設定-----------
        self.tree_ctrl_1.Bind(wx.EVT_MOTION, self.onShowToolTip)
        #----------timerの設定-------------------------
        fileName = os.environ["LogFile"]
        if fileName != os.environ["HOME"]:
            self.fread=open(fileName)         #lofFileをopen
            self.Bind(wx.EVT_TIMER, self.onTimerEventLog)
            self.timer = wx.Timer(self)
            self.setTimerInterval()

        #-----------windowのサイズ、分割を設定（最後で設定）
        #wxのversionによって処理変更
        ver = wx.version().split()[0]
        addVer = version.split("+")
        if ver >= "3.0" and len(addVer) == 1:
            #statusBar分（28）小さめにsizeを設定
            self.SetSizeWH(treeSize[0], treeSize[1]-28)
        else:
            self.SetSizeWH(treeSize[0], treeSize[1])
        if os.getenv("log") == "no":
            self.window_1.Unsplit(self.window_1_pane_2)
            #item = self.tree_ctrl_1.GetSelection()
            #print "----", self.tree_ctrl_1.IsVisible(item)

    def __set_properties(self):
        global envOpenFOAMFix, fontSize
        fontSize = self.label_1.GetFont().GetPointSize()        #fontSizeを取得
        # begin wxGlade: MyFrame.__set_properties
        self.SetTitle(_("TreeFoam"))
        self.SetSize((936, 592))
        self.frame_1_statusbar.SetStatusWidths([-1])
        # statusbar fields
        frame_1_statusbar_fields = [_("frame_1_statusbar")]
        for i in range(len(frame_1_statusbar_fields)):
            self.frame_1_statusbar.SetStatusText(frame_1_statusbar_fields[i], i)
        self.frame_1_toolbar.SetToolSeparation(10)
        self.frame_1_toolbar.Realize()
        self.panel_4.SetMinSize((135, 18))
        self.panel_3.SetBackgroundColour(wx.Colour(233, 255, 240))
        self.panel_6.SetMinSize((135, 18))
        self.panel_1.SetBackgroundColour(wx.Colour(233, 255, 240))
        self.panel_5.SetMinSize((135, 18))
        self.combo_box_1.SetMinSize((180, 28))
        self.combo_box_1.SetSelection(-1)
        self.combo_box_2.SetMinSize((180, 28))
        self.button_1.SetMinSize((50, 30))
        self.button_1.SetToolTipString(_(u"controlDictを開く"))
        self.panel_2.SetBackgroundColour(wx.Colour(233, 255, 240))
        self.button_2.SetMinSize((50, 20))
        self.button_2.SetFont(wx.Font(10, wx.DEFAULT, wx.NORMAL, wx.NORMAL, 0, "VL ゴシック"))
        self.button_2.SetToolTipString(_(u"logファイルを開く"))
        # end wxGlade


        self.SetTitle("TreeFoam_" + version + " (" + nTreeFoam + ")")
        self.window_1.SetSashGravity(1.0)

        self.clearStatus()
        self.readConfig()
        self.getConfig()
        self.setSolverInLabel("")
        getTreeDirUntilCurrCase(rootDir, selCaseDir)
        self.tree_ctrl_1 = wx.gizmos.TreeListCtrl(self, -1,
            size=(900,300), 
            style=
                wx.TR_DEFAULT_STYLE
                | wx.TR_FULL_ROW_HIGHLIGHT
                | wx.TR_HAS_BUTTONS
                | wx.TR_MULTIPLE
            )
        self.tree_ctrl_1.AddColumn("Tree")
        self.tree_ctrl_1.AddColumn("solver")
        self.tree_ctrl_1.AddColumn("BCPn")
        self.tree_ctrl_1.AddColumn("nR")
        self.tree_ctrl_1.AddColumn("st")
        self.tree_ctrl_1.AddColumn("ed")
        self.tree_ctrl_1.SetMainColumn(0)
        self.tree_ctrl_1.SetColumnWidth(0, colWidth[0])
        self.tree_ctrl_1.SetColumnWidth(1, colWidth[1])
        self.tree_ctrl_1.SetColumnWidth(2, colWidth[2])
        self.tree_ctrl_1.SetColumnWidth(3, colWidth[3])
        self.tree_ctrl_1.SetColumnWidth(4, colWidth[4])
        self.tree_ctrl_1.SetColumnWidth(5, colWidth[5])
        self.tree_ctrl_1.SetMinSize((700, 50))
        self.tree_ctrl_1.SetBackgroundColour(wx.Colour(229, 229, 229))

        #treeCtrlへimageセット
        self.folderImg = wx.Bitmap("./icons/folder16.png", wx.BITMAP_TYPE_PNG)
        self.folderDocImg = wx.Bitmap("./icons/folder-documents16.png", wx.BITMAP_TYPE_PNG)
        self.fileImg = wx.Bitmap("./icons/x-office-document16.png", wx.BITMAP_TYPE_PNG)
        self.fileCheckImg = wx.Bitmap("./icons/x-office-document_check16.png", wx.BITMAP_TYPE_PNG)
        self.checkImg = wx.Bitmap("./icons/edit-copyCheck16.png", wx.BITMAP_TYPE_PNG)
        self.folderCheckImg = wx.Bitmap("./icons/folderCheck16.png", wx.BITMAP_TYPE_PNG)
        self.salomeImg = wx.Bitmap("./icons/edit-copy16.png", wx.BITMAP_TYPE_PNG)
        ilist = wx.ImageList(16,16)
        self.fldridx = ilist.Add(self.folderImg)
        self.OFidx = ilist.Add(self.fileImg)
        self.OFsolveridx = ilist.Add(self.folderDocImg)
        self.salomeCheckidx = ilist.Add(self.checkImg)
        self.salomeidx = ilist.Add(self.salomeImg)
        self.folderCheckidx = ilist.Add(self.folderCheckImg)
        self.solveCaseidx = ilist.Add(self.fileCheckImg)
        self.tree_ctrl_1.AssignImageList(ilist)
        #treeDataのセット
        root = self.tree_ctrl_1.AddRoot(treeData[0])
        rootName = self.tree_ctrl_1.GetItemText(root)
        data = self.setValue()
        self.AddTreeNodes(root, data)
        self.tree_ctrl_1.SetItemImage(root, self.fldridx,
            wx.TreeItemIcon_Normal)
        caseDir = selCase
        self.setInitialImage(caseDir)
        self.setSelectCase(caseDir)
        #label上のbitmapを表示
        self.bitmap_1.Show()        #.Hide()で隠れている場合があるので、表示させる。
        self.bitmap_1.SetBitmap(self.folderDocImg)
        self.bitmap_2.SetBitmap(self.fileCheckImg)
        #text_ctrlのフォントサイズを設定
        font = self.text_ctrl_1.GetFont()
        font.SetPointSize(int(fontSize*0.9))
        self.text_ctrl_1.SetFont(font)
        #openLogFileボタンのフォントサイズを設定
        font.SetPointSize(int(fontSize*0.8))
        self.button_2.SetFont(font)
        self.label_13.SetLabel(os.environ["LogFile"])



    def __do_layout(self):
        # begin wxGlade: MyFrame.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_12 = wx.BoxSizer(wx.VERTICAL)
        sizer_13 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_17 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_14 = wx.BoxSizer(wx.VERTICAL)
        sizer_2 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_7 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_9 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_20 = wx.BoxSizer(wx.VERTICAL)
        sizer_21 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_29 = wx.BoxSizer(wx.VERTICAL)
        sizer_30 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_6 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_8 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_15 = wx.BoxSizer(wx.VERTICAL)
        sizer_16 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_31 = wx.BoxSizer(wx.VERTICAL)
        sizer_32 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_11 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_18 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_19 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_3 = wx.BoxSizer(wx.VERTICAL)
        sizer_10 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_22 = wx.BoxSizer(wx.VERTICAL)
        sizer_23 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_14.Add(self.static_line_7, 0, wx.BOTTOM | wx.EXPAND, 4)
        sizer_23.Add(self.label_1, 0, wx.ALIGN_RIGHT, 0)
        sizer_22.Add(sizer_23, 1, wx.ALIGN_RIGHT, 0)
        self.panel_4.SetSizer(sizer_22)
        sizer_11.Add(self.panel_4, 0, wx.EXPAND, 0)
        sizer_19.Add(self.label_3, 0, 0, 0)
        sizer_10.Add(self.label_11, 0, wx.RIGHT, 3)
        sizer_10.Add(self.label_6, 0, wx.RIGHT, 50)
        sizer_3.Add(sizer_10, 1, wx.ALIGN_RIGHT, 0)
        sizer_19.Add(sizer_3, 1, wx.EXPAND, 0)
        self.panel_3.SetSizer(sizer_19)
        sizer_18.Add(self.panel_3, 1, wx.EXPAND, 0)
        sizer_18.Add((5, 20), 0, 0, 0)
        sizer_11.Add(sizer_18, 1, wx.EXPAND, 0)
        sizer_14.Add(sizer_11, 0, wx.EXPAND, 0)
        sizer_32.Add(self.label_2, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_31.Add(sizer_32, 1, wx.ALIGN_RIGHT, 0)
        self.panel_6.SetSizer(sizer_31)
        sizer_4.Add(self.panel_6, 0, wx.EXPAND, 0)
        sizer_8.Add(self.bitmap_2, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 3)
        sizer_8.Add(self.label_5, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_16.Add(self.label_8, 0, wx.RIGHT | wx.ALIGN_RIGHT | wx.ALIGN_BOTTOM, 110)
        sizer_16.Add(self.label_9, 0, wx.RIGHT | wx.ALIGN_RIGHT | wx.ALIGN_BOTTOM, 100)
        sizer_16.Add(self.label_10, 0, wx.ALIGN_BOTTOM, 0)
        sizer_15.Add(sizer_16, 1, wx.ALIGN_RIGHT, 0)
        sizer_8.Add(sizer_15, 1, wx.EXPAND, 0)
        self.panel_1.SetSizer(sizer_8)
        sizer_6.Add(self.panel_1, 1, wx.EXPAND, 0)
        sizer_4.Add(sizer_6, 1, wx.EXPAND, 0)
        sizer_4.Add((5, 20), 0, 0, 0)
        sizer_14.Add(sizer_4, 0, wx.EXPAND, 0)
        sizer_30.Add(self.label_4, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_29.Add(sizer_30, 1, wx.ALIGN_RIGHT, 0)
        self.panel_5.SetSizer(sizer_29)
        sizer_5.Add(self.panel_5, 0, wx.EXPAND, 0)
        sizer_9.Add(self.bitmap_1, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 3)
        sizer_9.Add(self.label_7, 0, wx.LEFT | wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_21.Add(self.combo_box_1, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 10)
        sizer_21.Add(self.combo_box_2, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_21.Add(self.button_1, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_20.Add(sizer_21, 0, wx.ALIGN_RIGHT, 0)
        sizer_9.Add(sizer_20, 1, wx.EXPAND, 0)
        self.panel_2.SetSizer(sizer_9)
        sizer_7.Add(self.panel_2, 1, wx.EXPAND, 0)
        sizer_5.Add(sizer_7, 1, wx.EXPAND, 0)
        sizer_5.Add((5, 20), 0, 0, 0)
        sizer_14.Add(sizer_5, 0, wx.EXPAND, 0)
        sizer_14.Add((500, 5), 0, 0, 0)
        sizer_2.Add((5, 300), 0, 0, 0)
        sizer_2.Add(self.tree_ctrl_1, 1, wx.RIGHT | wx.EXPAND | wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_2.Add((5, 100), 0, 0, 0)
        sizer_14.Add(sizer_2, 1, wx.EXPAND, 0)
        sizer_14.Add((100, 10), 0, 0, 0)
        self.window_1_pane_1.SetSizer(sizer_14)
        sizer_17.Add(self.label_12, 0, wx.LEFT, 10)
        sizer_17.Add(self.button_2, 0, wx.LEFT, 20)
        sizer_17.Add(self.label_13, 0, wx.LEFT, 5)
        sizer_12.Add(sizer_17, 0, wx.EXPAND, 0)
        sizer_13.Add(self.text_ctrl_1, 1, wx.LEFT | wx.RIGHT | wx.BOTTOM | wx.EXPAND, 5)
        sizer_12.Add(sizer_13, 1, wx.EXPAND, 0)
        self.window_1_pane_2.SetSizer(sizer_12)
        self.window_1.SplitHorizontally(self.window_1_pane_1, self.window_1_pane_2)
        sizer_1.Add(self.window_1, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_1)
        self.Layout()
        # end wxGlade


    #------menu bar ----------------------

    #configTreeFoamの変更
    def selChangeConfigTreeFoam(self, event): # wxGlade: MyFrame.<event_handler>
        self.onChangeConfigTreeFoam(event)
        event.Skip()

    #rootDirの変更
    def selChangeRoot(self, event): # wxGlade: MyFrame.<event_handler>
        self.writeStatus(_(u"rootDirを変更中..."))
        root = self.tree_ctrl_1.GetRootItem()
        editName = self.tree_ctrl_1.GetItemText(root)
        self.changeRoot(editName)
        self.clearStatus()
        event.Skip()

    #終了
    def selExit(self, event): # wxGlade: MyFrame.<event_handler>
        treeSize = self.GetSize()
        colWidth = [self.tree_ctrl_1.GetColumnWidth(0),
                    self.tree_ctrl_1.GetColumnWidth(1),
                    self.tree_ctrl_1.GetColumnWidth(2),
                    self.tree_ctrl_1.GetColumnWidth(3),
                    self.tree_ctrl_1.GetColumnWidth(4),
                    self.tree_ctrl_1.GetColumnWidth(5)]
        if self.window_1.IsSplit() == True:
            splitWidth = self.window_1.GetSashPosition()
        else:
            splitWidth = -1
        try:
            self.writeConfig()
            endingTreeFoam(treeSize, colWidth, splitWidth)
        except:
            title = _(u"エラー")
            message = _(u"書込エラーが発生しました。\n  強制終了します。")
            self.errDialog(title, message)
        self.Destroy()
        #systemClipBoard使用のため、終了処理追加
        #gtk.main_quit()
        return False
        

    #reload
    def selReload(self, event): # wxGlade: MyFrame.<event_handler>
        global solveCaseFix, selCaseDirFix
        self.writeStatus(_(u"tree data を読み込み中..."))
        #currentCaseを保存
        item = self.tree_ctrl_1.GetSelection()
        selCaseDir = self.getDirectory(item)
        #再読込
        self.reloadItems()
        #caseName, solverをlabelにセット
        caseItem = self.getItem(solveCaseFix)
        self.changeSolveCase(caseItem)
        #currentCaseを設定
        self.setSelectCase(self.convDirToList(selCaseDir))
        self.clearStatus()
        #currentDirを設定
        currDir = os.environ["TreeFoamPath"]
        os.chdir(currDir)
        event.Skip()

    #help
    def selUsage(self, event): # wxGlade: MyFrame.<event_handler>
        print _("ヘルプを表示します。")
        treeFoamDir = getTreeFoamInstallDir()
        #firefox終了時エラーが出るので、firefoxのエラー表示をキャンセル
        command = "firefox " + treeFoamDir + "/help/TreeFoam-manual.pdf 2> /dev/null &"
        os.system(command)

    #version表示
    def selVersion(self, event): # wxGlade: MyFrame.<event_handler>
        global version
        print _(u"versionを表示します。")
        title = _(u"version表示")
        message = _(u"TreeFoamのバージョンを表示します。\n\n")
        message += _(u"  TreeFoam ") + version
        message += _(u"\n\n\n                programed by s.fujii  ")
        self.okDialog(title, message)

    #newCase
    def selNewCase(self, event): # wxGlade: MyFrame.<event_handler>
        print _(u"新しいcaseを作成します。")
        self.createAndChangeCase()

    #currentCase（解析caseの設定）
    def selSetCurrCase(self, event): # wxGlade: MyFrame.<event_handler>
        item = self.tree_ctrl_1.GetSelection()
        self.changeSolveCase(item)
        event.Skip()

    #topoSetEditorの起動
    def selRunTopoSetEditor(self, event):  # wxGlade: MyFrame.<event_handler>
        print _(u"topoSetEditorを起動します。")
        self.runTopoSetEditor()

    #multiRegionの設定
    def selSetMultiRegion(self, event):  # wxGlade: MyFrame.<event_handler>
        self.setMultiRegion(event)
        event.Skip()

    #helyxOSによる編集
    def selHelyxos(self, event):  # wxGlade: MyFrame.<event_handler>
        print _(u"helyxOSで編集します。")
        self.runHelyxos()

    #gridEditor起動
    def selGridEditor(self, event): # wxGlade: MyFrame.<event_handler>
        self.onGridEditor(event)
        event.Skip()

    #field編集
    def selEditField(self, event): # wxGlade: MyFrame.<event_handler>
        global nTreeFoam
        if self.checkFolderMsg(solveCaseFix) == "case":
            os.chdir(solveCaseFix)
            numFolder = self.getSelectionTime()
            editDir = solveCaseFix + "/" + numFolder
            if len(glob.glob(editDir)) > 0:
                job = "editField"
                title = _(u"'boundary Field の編集'")
                img = "boundary"
                mess = _(u"'boundary Field を編集します'")
                comm  = "selectFieldsForEditDialog.py " + nTreeFoam + " "
                comm += job + " " + title + " " + img + " " + mess + " " + editDir
                comm += " &"
                os.system(comm.encode("utf-8"))
            else:
                self.noNumFolderMsg()
        event.Skip()

    #properties編集
    def selEditProperties(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkFolderMsg(solveCaseFix) == "case":
            self.editPropertiesFiles()
        event.Skip()

    #Dict編集
    def selEditDict(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkFolderMsg(solveCaseFix) == "case":
            self.editDict()
        event.Skip()

    #mesh編集
    def selEditMesh(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkFolderMsg(solveCaseFix) == "case":
            #os.chdir(solveCaseFix)
            #meshOperationDialog.Show()
            self.runEditMesh()
        event.Skip()

    #フォルダ名変更
    def selRenameCase(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkMultiSelection(_(u"フォルダ名変更"))==False:
            self.renameFolder()
        event.Skip()

    #フォルダ追加
    def selAddFolder(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkMultiSelection(_(u"フォルダ追加"))==False:
            self.insertFolder()
        event.Skip()

    #フォルダ削除
    def selDeleteFolder(self, event): # wxGlade: MyFrame.<event_handler>
        self.deleteFolders()
        event.Skip()

    #runSolver
    def selRunSolver(self, event): # wxGlade: MyFrame.<event_handler>
        self.runSolver(solveCaseFix)
        event.Skip()

    #plotWatcher
    def selPlotWatcher(self, event): # wxGlade: MyFrame.<event_handler>
        self.onPlotWatcher(event)

    #並列計算
    def selParallelSolver(self, event): # wxGlade: MyFrame.<event_handler>
        self.onParallel(event)
        event.Skip()

    #FOAM端末
    def selRunFoamTerm(self, event): # wxGlade: MyFrame.<event_handler>
        global solveCaseFix
        self.runFoamTermDir(solveCaseFix)
        event.Skip()

    #paraFoam
    def selRunParaFoam(self, event): # wxGlade: MyFrame.<event_handler>
        self.onRunParaFoam(event)
        event.Skip()

    #foamViewer
    def selRunFoamViewer(self, event): # wxGlade: MyFrame.<event_handler>
        print "Event handler `selRunFoamViewer' not implemented"
        event.Skip()

    #runSlomeMeca
    def selRunSalome(self, event): # wxGlade: MyFrame.<event_handler>
        self.runSalomeMeca(solveCaseFix)
        event.Skip()

    #folderOpen
    def selFolderOpen(self, event): # wxGlade: MyFrame.<event_handler>
        self.onFolderOpen(event)
        event.Skip()

    #dataSetClear
    def selDataSetClear(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkFolderMsg(solveCaseFix) == "case":
            os.chdir(solveCaseFix)
            timeFolder = self.getSelectionTime()
            if len(glob.glob(timeFolder)) > 0:
                comm  = "cd " + solveCaseFix + ";"
                comm += "setDataInFieldsDialog.py " + solveCaseFix + " " + timeFolder + " &"
                os.system(comm)
            else:
                self.noNumFolderMsg()
        event.Skip()

    #runCAD
    def selRunCAD(self, event): # wxGlade: MyFrame.<event_handler>
        self.runCAD(solveCaseFix)
        event.Skip()

    #folderCopy
    def selCopyFolder(self, event): # wxGlade: MyFrame.<event_handler>
        self.foldersCopy()
        event.Skip()

    #folderPaste
    def selPasteFolder(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkMultiSelection(_(u"貼付け"))==False:
            self.foldersPaste()
        event.Skip()

    #caseCopy
    #def selCaseCopy(self, event): # wxGlade: MyFrame.<event_handler>
    #    self.casesCopy()
    #    event.Skip()

    #casePaste
    def selCasePaste(self, event):  # wxGlade: MyFrame.<event_handler>
        self.casesPaste()
        event.Skip()

    #timerEventLog
    def onTimerEventLog(self, event):
        self.timerEventLog(event)

    #openLogFile
    def onOpenLogFile(self, event):  # wxGlade: MyFrame.<event_handler>
        self.openLogFile(event)

    #-----------------------------------------------------

    #
    #  openLogFile
    #    logFileをオープンする
    def openLogFile(self, event):
        logFile = os.environ["LogFile"]
        pyTreeFoam.runEditor(logFile)

    #
    #  timerEventLog
    #    timerイベントでlogを出力、画面の設定
    def timerEventLog(self, event):
        global frameShow
        #timerEventを停止
        self.timer.Stop()
        #logを読み込む
        addText = self.fread.read()
        if addText != "":
            self.text_ctrl_1.AppendText(addText)
            pass
        #frameの表示状態を確認
        if frameShow == "showing":
            #windowの分割設定
            self.window_1.SetSashPosition(splitWidth, True)
            frameShow = "showed"
        elif frameShow == "showed":
            frameShow = "showSet"
        #選択行を表示させる
        elif frameShow == "showSet":
            item = self.tree_ctrl_1.GetSelection()
            self.tree_ctrl_1.ScrollTo(item)
            #最後にwindowSizeを設定
            self.SetSize(treeSize)
            frameShow = "set"

        #timerスタート
        self.setTimerInterval()

    #  setTimerInterval
    #    eventのIntervalのセット
    def setTimerInterval(self):
        self.timer.Start(200)       #intervalの設定（0.1s）

    #  setSolverInLabel
    #    label内にsolver名表示、solverアイコン表示
    def setSolverInLabel(self, solver):
        label = solver
        self.label_7.SetLabel(label)
        self.Layout()
        if solver == "":
            self.bitmap_1.Hide()
        else:
            self.bitmap_1.Show()

    # checkFolderMesg
    def checkFolderMsg(self, directory):
        global folderMsg
        ans = checkFolder(directory)
        if folderMsg == "yes":
            if ans != "case":
                title = _(u"警告")
                message = _(u"OpenFOAMのCaseフォルダではありません。")
                self.warningDialog(title, message)
        return ans

    # AddTreeNode
    def AddTreeNodes(self, parentItem, items):
        for item in items:
            #if type(item) == str:
            if type(item) == str or type(item) == unicode:
                newItem = self.tree_ctrl_1.AppendItem(parentItem, item)
                self.tree_ctrl_1.SetItemImage(newItem, self.fldridx,
                    wx.TreeItemIcon_Normal)
            else:
                newItem = self.tree_ctrl_1.AppendItem(parentItem, item[0])
                self.AddTreeNodes(newItem, item[1])
                self.tree_ctrl_1.SetItemImage(newItem, self.fldridx,
                    wx.TreeItemIcon_Normal)

    #
    # setValue
    #   treeのデータ構造
    #    ['root', [
    #        '0', 
    #        ['constant', [
    #             ['polyMesh', [
    #                'sets',
    #                'sets.bak',
    #                'sss']]]], 
    #        'model',
    #        'solve.log.analyzed', 
    #        ['system', [
    #            'test']]]]
    #
    def setValue(self):
        global treeData
        data = treeData[1]
        return data

    # setSelectCase
    #  treeDataからcurrentCaseをselectする
    def setSelectCase(self, dataDir):
        i=0
        while (i<len(dataDir)):
            if type(dataDir[i]) == str:
                dataDir[i] = dataDir[i].decode("utf-8")
            i=i+1
        parent = self.tree_ctrl_1.GetRootItem()
        #name = self.tree_ctrl_1.GetItemText(parent)
        i=1
        while (i<len(dataDir)):
            self.tree_ctrl_1.Expand(parent)
            #全chilrenをチェック
            items = self.getChildrenItems(parent)
            itemNames = self.getChildrenList(parent)
            ii=0
            while ii<len(itemNames):
                if type(itemNames[ii]) == str:
                    itemNames[ii] = itemNames[ii].decode("utf-8")
                ii=ii+1
            flag = 0
            ii=0
            while ii<len(itemNames):
                if itemNames[ii] == dataDir[i]:
                    parent = items[ii]
                    flag = 1
                    break
                ii=ii+1
            if flag == 0:
                if dataDir[1] != "":
                    print dataDir, _(u"のDirがありません。")
                break
            i=i+1
        self.tree_ctrl_1.SelectItem(parent, parent, True)
        #item = self.tree_ctrl_1.GetSelection()
        #self.tree_ctrl_1.EnsureVisible(item)
        #self.tree_ctrl_1.ScrollTo(item)


    # setBackgroundColour
    #   treeのbackgroundColourを設定（treeを縞模様に設定）
    def setBackgroundColour(self):
        global solveCaseFix
        caseDirList = self.convDirToList(solveCaseFix)
        caseDir = string.join(caseDirList, "/")
        parent = self.tree_ctrl_1.GetRootItem()
        #parentName = self.tree_ctrl_1.GetItemText(parent)
        parentName = self.getTreeNameFromItem(parent)
        setDir = parentName
        n=0
        n = self.checkColour(n, parent, setDir, caseDir)

    def checkColour(self, n, parent, setDir, caseDir):
        #parentのchildren[]を取得
        children = self.getChildrenList(parent)
        #全childrenをチェック
        item, cookie = self.tree_ctrl_1.GetFirstChild(parent)
        for child in children:
            if (n % 2) == 0:
                #self.tree_ctrl_1.SetItemBackgroundColour(item, wx.Colour(235, 235, 235))
                self.tree_ctrl_1.SetItemBackgroundColour(item, wx.Colour(238, 238, 235))
            else:
                #self.tree_ctrl_1.SetItemBackgroundColour(item, "litegray")
                self.tree_ctrl_1.SetItemBackgroundColour(item, "lightgray")
            newDir = setDir + "/" + child
            if newDir == caseDir:
                self.tree_ctrl_1.SetItemBackgroundColour(item, "white")
            if self.tree_ctrl_1.IsExpanded(item) == True:
                n += 1
                n = self.checkColour(n, item, newDir, caseDir)
            n += 1
            item, cookie = self.tree_ctrl_1.GetNextChild(parent, cookie)
        n += 1
        return n



    # setInitialImage
    #  TreeDataにイメージデータを設定
    def setInitialImage(self, caseDir):
        global solveCaseFix
        parent = self.tree_ctrl_1.GetRootItem()
        #parentName = self.tree_ctrl_1.GetItemText(parent)
        parentName = self.getTreeNameFromItem(parent)
        setDir = parentName
        for folder in caseDir[1:]:
            #parentのchildren[]を取得
            children = self.getChildrenList(parent)
            #全childrenをチェック
            item, cookie = self.tree_ctrl_1.GetFirstChild(parent)
            for child in children:
                checkDir = setDir + "/" + child
                checkResult = checkFolder(checkDir)
                if (checkResult == "case"):
                    itemOF = item
                    [solver, BC] = getSolverBC(checkDir)
                    nRst = getNumberResult(checkDir)
                    self.setItemOFImage(itemOF, solver, nRst, BC)
                elif (checkResult == "salome"):
                    self.tree_ctrl_1.SetItemImage(item, self.salomeidx, 0,
                        wx.TreeItemIcon_Normal)
                item, cookie = self.tree_ctrl_1.GetNextChild(parent, cookie)
            item, cookie = self.tree_ctrl_1.GetFirstChild(parent)
            for child in children:
                parentName = ""
                if type(folder) == str:
                    folder = folder.decode("utf-8")
                if folder == child:
                    parent = item
                    #parentName = self.tree_ctrl_1.GetItemText(parent)
                    parentName = self.getTreeNameFromItem(parent)
                    setDir = setDir + "/" + parentName
                    break
                item, cookie = self.tree_ctrl_1.GetNextChild(parent, cookie)
            if parentName == "":
                break

    # setChildrenImage
    #  childrenにイメージをセット
    def setChildrenImage(self, parent):
        childrenItems = self.getChildrenItems(parent)
        for childItem in childrenItems:
            checkDir = self.getDirectory(childItem)
            checkResult = checkFolder(checkDir)
            if (checkResult == "case"):
                [solver, BC] = getSolverBC(checkDir)
                nRst = getNumberResult(checkDir)
                self.setItemOFImage(childItem, solver, nRst, BC)                
            elif (checkResult == "salome"):
                self.tree_ctrl_1.SetItemImage(childItem, self.salomeidx, 0,
                    wx.TreeItemIcon_Normal)

    # setChildrenImageSolveCase
    #  childrenに解析caseがあればimageをセット
    def setChildrenImageSolveCase(self, parent):
        childrenItems = self.getChildrenItems(parent)
        for childItem in childrenItems:
            checkDir = self.getDirectory(childItem)
            if checkDir == solveCaseFix:
                checkResult = checkFolder(checkDir)
                if (checkResult == "folder"):
                    self.tree_ctrl_1.SetItemImage(childItem, self.folderCheckidx,
                        0, wx.TreeItemIcon_Normal)
                elif checkResult == "case":
                    self.tree_ctrl_1.SetItemImage(childItem, self.solveCaseidx,
                        0, wx.TreeItemIcon_Normal)
                else:
                    self.tree_ctrl_1.SetItemImage(childItem, self.salomeCheckidx,
                        0, wx.TreeItemIcon_Normal)

    # setItemOFImage
    #  OpenFoamのImageをセット
    def setItemOFImage(self, itemOF, solver, nRst, BC):
        self.tree_ctrl_1.SetItemImage(itemOF, self.OFidx, 0,
            wx.TreeItemIcon_Normal)
        self.tree_ctrl_1.SetItemText(itemOF, solver, 1)
        self.tree_ctrl_1.SetItemImage(itemOF, self.OFsolveridx,1,
            wx.TreeItemIcon_Normal)
        if len(nRst)>0:
            BCP = " " + BC + "P" + nRst[-1]
            self.tree_ctrl_1.SetItemText(itemOF, BCP, 2)
            self.tree_ctrl_1.SetItemText(itemOF, nRst[0], 3)
            self.tree_ctrl_1.SetItemText(itemOF, nRst[1], 4)
            self.tree_ctrl_1.SetItemText(itemOF, nRst[2], 5)

    # getItem
    #  directoryからTreeItemを取得
    def getItem(self, directory):
        global rootDir
        treeDir = directory[len(rootDir)+1:].split("/")
        parent = self.tree_ctrl_1.GetRootItem()
        for name in treeDir:
            childrenItem = self.getChildrenItems(parent)
            flag = 0
            for item in childrenItem:
                #child = self.tree_ctrl_1.GetItemText(item)
                child = self.getTreeNameFromItem(item)
                if name == child:
                    flag = 1
                    break
            if flag == 1:
                parent = item
            else:
                ans = ""
                break
        ans = item
        return ans

    # getDirectory
    #  TreeDataからdirectoryを取得
    def getDirectory(self, item):
        #name = self.tree_ctrl_1.GetItemText(item)
        name = self.getTreeNameFromItem(item)
        selectDir = ""
        while (name != ""):
            selectDir = "/" + name + selectDir
            item = self.tree_ctrl_1.GetItemParent(item)
            name = self.getTreeNameFromItem(item)
        selectDir = selectDir[1:]
        return selectDir

    #  getTreeNameFromItem
    #    itemからTreeNameを取得
    def getTreeNameFromItem(self, item):
        if item.IsOk():
            name = self.tree_ctrl_1.GetItemText(item)
        else:
            name = ""
        return name

    # getChildrenList
    #  親itemから子のtextを取得
    def getChildrenList(self, parent):
        children = []
        #firstChild
        item, cookie = self.tree_ctrl_1.GetFirstChild(parent)
        while item:
            children.append(self.tree_ctrl_1.GetItemText(item, 0))
            #nextChild
            item, cookie = self.tree_ctrl_1.GetNextChild(parent, cookie)
        return children

    #
    #  getChildrenItems
    #    親itemから子itemを取得
    def getChildrenItems(self, parent):
        items = []
        #firstChild
        item, cookie = self.tree_ctrl_1.GetFirstChild(parent)
        while item:
            items.append(item)
            #nextChild
            item, cookie = self.tree_ctrl_1.GetNextChild(parent, cookie)
        return items

    #
    #  addGrandChildren
    #    親itemから孫itemを追加
    def addGrandChildren(self, parent):
        childrenItems = self.getChildrenItems(parent)
        for childItem in childrenItems:
            directory = self.getDirectory(childItem)
            folders = getFoldersOnlyCurrDir(directory)
            folders.sort()
            for folder in folders:
                itemText = folder.split("/")[-1]
                check = checkFolder(folder)
                if (check == "folder"):
                    newItem = self.tree_ctrl_1.AppendItem(childItem, itemText)
                    self.tree_ctrl_1.SetItemImage(newItem, self.fldridx,
                        wx.TreeItemIcon_Normal)
                elif (check == "case"):
                    newItem = self.tree_ctrl_1.AppendItem(childItem, itemText)
                    [solver, BC] = getSolverBC(folder)
                    nRst = getNumberResult(folder)
                    self.setItemOFImage(newItem, solver, nRst, BC)
                elif (check == "salome"):
                    newItem = self.tree_ctrl_1.AppendItem(childItem, itemText)
                    self.tree_ctrl_1.SetItemImage(newItem, self.salomeidx,
                        wx.TreeItemIcon_Normal)


    #
    #  delGrandChildrenItem
    #    孫itemの削除
    def delGrandChildrenItem(self, parent):
        children = self.getChildrenItems(parent)
        for childItem in children:
            self.tree_ctrl_1.DeleteChildren(childItem)

    def collapseChildren(self, parent):
        children = self.getChildrenItems(parent)
        for childItem in children:
            self.tree_ctrl_1.Collapse(childItem)

    def reloadItems(self):
        global rootDir, selCaseDir, treeData
        #treeをクリア
        self.writeStatus(_(u"tree data を読み込み中..."))
        self.tree_ctrl_1.DeleteAllItems()
        #rootのdirを取得
        self.getConfig()
        selCaseDir = rootDir
        #次の1行を修正 13/01/31
        treeData = getTreeDirOnlylRootChildren(rootDir)
        root = self.tree_ctrl_1.AddRoot(treeData[0])
        rootName = self.tree_ctrl_1.GetItemText(root)
        #treeDataの作成
        data = treeData[1]
        self.AddTreeNodes(root, data)
        self.tree_ctrl_1.SetItemImage(root, self.fldridx,
            wx.TreeItemIcon_Normal)
        #selCaseの設定
        self.getConfig()
        caseDir = self.convDirToList(selCaseDir)
        self.setInitialImage(caseDir)
        self.setSelectCase(caseDir)
        self.setSolveCase()
        item = self.tree_ctrl_1.GetSelection()
        self.tree_ctrl_1.ScrollTo(item)
        item = self.getItem(solveCaseFix)
        checkResult = checkFolder(solveCaseFix)
        if checkResult == "folder":
            self.tree_ctrl_1.SetItemImage(item, self.folderCheckidx, 0,
                wx.TreeItemIcon_Normal)
        elif checkResult == "case":
            self.tree_ctrl_1.SetItemImage(item, self.solveCaseidx, 0,
                wx.TreeItemIcon_Normal)
        else:
            self.tree_ctrl_1.SetItemImage(item, self.salomeCheckidx, 0,
                wx.TreeItemIcon_Normal)
        #編集するtimeFolderを設定
        self.setEditTimeFolder(solveCaseFix)
        self.setSolverStopTime(solveCaseFix)

    def convDirToList(self, dataDir):
        global rootDir
        ans = []
        dataNames = dataDir[len(rootDir)+1:].split("/")
        ans.append(rootDir)
        for name in dataNames:
            ans.append(name)
        return ans

    def setSolveCase(self):
        global solveCaseFix, rootDir
        saveItem =  self.tree_ctrl_1.GetSelection()
        caseDir = self.convDirToList(solveCaseFix)
        self.setSelectCase(caseDir)
        item = self.tree_ctrl_1.GetSelection()
        self.tree_ctrl_1.SetItemTextColour(item, "Red")
        #self.tree_ctrl_1.SetItemBold(item, True)
        self.tree_ctrl_1.SelectItem(saveItem, saveItem, True)    

    #
    #  changeSolveCase
    #    解析caseを変更
    def changeSolveCase(self, item):
        global solveCaseFix, rootDir, timeFolders, folderMsg
        #folderMsgErrorの表示を禁止
        folderMsg = "no"
        #変更前の解析Caseのfont色を元に戻す
        preItem = self.getItem(solveCaseFix)
        self.tree_ctrl_1.SetItemTextColour(preItem, sysFontColour)  #system色（黒）
        #変更前のiconを元に戻す
        preDir = self.getDirectory(preItem)
        if checkFolder(preDir) == "case":
            self.tree_ctrl_1.SetItemImage(preItem, self.OFidx,0,
                wx.TreeItemIcon_Normal)
        elif checkFolder(preDir) == "salome":
            self.tree_ctrl_1.SetItemImage(preItem, self.salomeidx,0,
                wx.TreeItemIcon_Normal)
        else:
            self.tree_ctrl_1.SetItemImage(preItem, self.fldridx,0,
                wx.TreeItemIcon_Normal)
        #解析Caseのfontを変更
        solveDir = self.getDirectory(item)
        self.setSelectCase(self.convDirToList(solveDir))
        self.tree_ctrl_1.SetItemTextColour(item, "Red")  #ff0000
        #self.tree_ctrl_1.SetItemTextColour(item, "#ff0000")  #ff0000
        #解析Caseのiconを設定
        checkResult = checkFolder(solveDir)
        if checkResult == "folder":
            self.tree_ctrl_1.SetItemImage(item, self.folderCheckidx,0,
                wx.TreeItemIcon_Normal)
            self.bitmap_2.SetBitmap(self.folderCheckImg)
        elif checkResult == "case":
            self.tree_ctrl_1.SetItemImage(item, self.solveCaseidx,0,
                wx.TreeItemIcon_Normal)
            self.bitmap_2.SetBitmap(self.fileCheckImg)
        else:
            self.tree_ctrl_1.SetItemImage(item, self.salomeCheckidx,0,
                wx.TreeItemIcon_Normal)
            self.bitmap_2.SetBitmap(self.checkImg)
        #lebelにDir, case, solverをセット, backGroundColourを設定
        solveCaseFix = solveDir
        self.setLabelDataInFrame()
        #時間フォルダの取得、設定
        self.setEditTimeFolder(solveCaseFix)
        self.setSolverStopTime(solveCaseFix)
        #解析CaseのbackGroundColourを設定（縞模様）
        self.setBackgroundColour()
        #folderMsgErrorの表示を許可
        folderMsg = "yes"

    #
    #  setLabelDataInFrame
    #    OpenFam環境設定ファイル、CaseDir、Case名、solver名を表示
    #    backGroundColourを設定
    def setLabelDataInFrame(self):
        global envOpenFOAMFix, solveCaseFix
        #labelを設定
        caseName = solveCaseFix.split("/")[-1]
        caseDir = solveCaseFix[:-len(caseName)-1]
        solver = getSolver(solveCaseFix)
        maxCharaLength = 60
        if len(caseDir) > maxCharaLength:
            caseDir = "..." + caseDir[-(maxCharaLength-3):]
        self.label_3.SetLabel(" " + caseDir)
        self.label_5.SetLabel(caseName)
        self.setSolverInLabel(solver)
        envOpenFOAM = envOpenFOAMFix.split("/")[-1]
        #self.label_6.SetLabel(envOpenFOAMFix)
        self.label_6.SetLabel(envOpenFOAM)
        #labelのbackGroundColorを設定
        if self.checkFolderMsg(solveCaseFix) == "case":
            #lightGreenに設定
            self.panel_1.SetBackgroundColour(wx.Colour(233, 255, 240))
            self.panel_2.SetBackgroundColour(wx.Colour(233, 255, 240))
            self.panel_3.SetBackgroundColour(wx.Colour(233, 255, 240))
        elif self.checkFolderMsg(solveCaseFix) == "salome":
            #lightYellowに設定
            self.panel_1.SetBackgroundColour(wx.Colour(244, 244, 147))
            self.panel_2.SetBackgroundColour(wx.Colour(244, 244, 147))
            self.panel_3.SetBackgroundColour(wx.Colour(244, 244, 147))
        else:
            #pinkに設定
            self.panel_1.SetBackgroundColour(wx.Colour(255, 233, 240))
            self.panel_2.SetBackgroundColour(wx.Colour(255, 233, 240))
            self.panel_3.SetBackgroundColour(wx.Colour(255, 233, 240))

    #
    #  setSolverStopTime
    #    solver停止方法設定
    def setSolverStopTime(self, solveCaseFix):
        global stopAt, endTime
        [endTime, stopAt] = getFoamContents.getEndTimeFolder(solveCaseFix)
        if stopAt == "":
            cont = [""]
        else:
            cont = []
            cont.append("endTime:" + endTime)
            cont.append("noWriteNow")
            cont.append("writeNow")
            cont.append("nextWrite")
        self.combo_box_2.Clear()
        self.combo_box_2.AppendItems(cont)
        if stopAt == "endTime":
            self.combo_box_2.SetSelection(0)
        elif stopAt == "noWriteNow":
            self.combo_box_2.SetSelection(1)
        elif stopAt == "writeNow":
            self.combo_box_2.SetSelection(2)
        elif stopAt == "nextWrite":
            self.combo_box_2.SetSelection(3)
        else:
            self.combo_box_2.SetSelection(0)


    #
    #  setEditTimeFolder
    #    編集するtimeFolderの設定
    def setEditTimeFolder(self, solveCaseFix):
        global latestTime, startTime, firstTime, startFrom
        timeFolders = pyTreeFoam.getTimeFolders(solveCaseFix)
        [latestTime, startTime, firstTime, startFrom] = getFoamContents.getLatestStartFirstTimeFolder(solveCaseFix)
        if latestTime == "":
            cont = [""]
        else:
            cont = []
            cont.append("firstTime")
            cont.append("startTime:" + startTime)
            cont.append("latestTime")
        self.combo_box_1.Clear()
        self.combo_box_1.AppendItems(cont)
        if startFrom == "firstTime":
            self.combo_box_1.SetSelection(0)
        elif startFrom == "startTime":
            self.combo_box_1.SetSelection(1)
        elif startFrom == "latestTime":
            self.combo_box_1.SetSelection(2)
        else:
            self.combo_box_1.SetSelection(0)

    #
    #  getSelectionTime
    #    選択しているTimeを取得
    def getSelectionTime(self):
        #lNo = self.combo_box_1.GetSelection()
        times = pyTreeFoam.getTimeFolders(solveCaseFix)
        startItem = self.combo_box_1.GetStringSelection()
        if startItem == "":
            #選択されていない場合、直接読む
            startItem = self.combo_box_1.GetValue()
        items = startItem.split(":")
        flag = 0
        if len(items) == 2:
            time = items[1]
            for timeR in times:
                if float(time)==float(timeR):
                    time = timeR
                    flag = 1
                    break
            if flag == 0:
                title = _(u"警告")
                mess = _(u"編集するtimeFolderがありません")
                mess += _(u"\nfirstTimeに設定しました")
                self.warningDialog(title, mess)
                time = times[0]
        else:
            startFrom = items[0]
            time = ""
            if startFrom == "firstTime":
                time = times[0]
            elif startFrom == "latestTime":
                time = times[-1]
        return time

    #--------メニューボタン-------------------

    #configTreeFoamの変更
    def onChangeConfigTreeFoam(self, event): # wxGlade: MyFrame.<event_handler>
        print _(u"configTreeFoamを変更します")
        self.changeConfigTreeFoam(event)
        event.Skip()

    #rootDirの変更
    def onChangeRoot(self, event): # wxGlade: MyFrame.<event_handler>
        self.selChangeRoot(event)
        event.Skip()

    #reload
    def onReload(self, event): # wxGlade: MyFrame.<event_handler>
        self.selReload(event)
        event.Skip()

    #newCase
    def onNewCase(self, event): # wxGlade: MyFrame.<event_handler>
        print _(u"新しいcaseを作成します。")
        self.createAndChangeCase()
        event.Skip()

    #multiRegionの設定
    def onSetMultiRegion(self, event):  # wxGlade: MyFrame.<event_handler>
        self.setMultiRegion(event)
        event.Skip()

    #currentCase
    def onActiveCase(self, event): # wxGlade: MyFrame.<event_handler>
        self.selSetCurrCase(event)
        event.Skip()

    #gridEditor起動
    def onGridEditor(self, event): # wxGlade: MyFrame.<event_handler>
        if self.checkFolderMsg(solveCaseFix) == "case":
            os.chdir(solveCaseFix)
            numFolder = self.getSelectionTime()
            editDir = solveCaseFix + "/" + numFolder
            if len(glob.glob(editDir)) > 0:
                self.runGridEditor(editDir)
            else:
                self.noNumFolderMsg()
        event.Skip()

    #field編集
    def onEditField(self, event): # wxGlade: MyFrame.<event_handler>
        self.selEditField(event)
        event.Skip()

    #properties編集
    def onEditProperties(self, event): # wxGlade: MyFrame.<event_handler>
        self.selEditProperties(event)
        event.Skip()

    #Dict編集
    def onEditDict(self, event): # wxGlade: MyFrame.<event_handler>
        self.selEditDict(event)
        event.Skip()

    #mesh編集
    def onEditMesh(self, event): # wxGlade: MyFrame.<event_handler>
        self.selEditMesh(event)
        event.Skip()

    #topoSetEditorの起動
    def onTopoSetEditor(self, event):  # wxGlade: MyFrame.<event_handler>
        self.runTopoSetEditor()

    #HelyxOS
    def onHelyxos(self, event): # wxGlade: MyFrame.<event_handler>
        print _(u"HelyxOSを起動中...")
        self.runHelyxos()

    #caseの初期化
    def onIniCase(self, event):  # wxGlade: MyFrame.<event_handler>
        print _(u"結果フォルダと不要なファイルを削除して、caseを初期化します。")
        self.caseInitialize()
        self.reloadItems()

    #deleteResult
    def onDeleteResult(self, event): # wxGlade: MyFrame.<event_handler>
        print _(u"結果フォルダを削除します。")
        self.deleteResultFolders()
        self.reloadItems()

    #runSlomeMeca
    def onRunSalome(self, event): # wxGlade: MyFrame.<event_handler>
        self.selRunSalome(event)
        event.Skip()

    #runSolver
    def onRunSolver(self, event): # wxGlade: MyFrame.<event_handler>
        self.selRunSolver(event)
        event.Skip()

    #plotWatcher
    def onPlotWatcher(self, event): # wxGlade: MyFrame.<event_handler>
        self.runPlotWatcher()

    #並列計算
    def onParallel(self, event): # wxGlade: MyFrame.<event_handler>
        global solveCaseFix, envOpenFOAMFix, folderMsg
        if self.checkFolderMsg(solveCaseFix) == "case":
            #runParallelDialog.Show(solveCaseFix)
            comm = "runParallelDialog.py " + solveCaseFix + " &"
            os.system(comm)
        event.Skip()

    #FOAM端末
    def onRunFoamTerm(self, event): # wxGlade: MyFrame.<event_handler>
        global solveCaseFix
        self.runFoamTermDir(solveCaseFix)
        event.Skip()

    #paraFoam
    def onRunParaFoam(self, event): # wxGlade: MyFrame.<event_handler>
        global solveCaseFix
        self.runParaFoamDir(solveCaseFix)
        #event.Skip()

    #runViewer
    def onRunViewer(self, event): # wxGlade: MyFrame.<event_handler>
        print "Event handler `onRunViewer' not implemented"
        event.Skip()

    #終了
    def onExit(self, event): # wxGlade: MyFrame.<event_handler>
        self.selExit(event)

    #folderOpen
    def onFolderOpen(self, event): # wxGlade: MyFrame.<event_handler>
        global solveCaseFix
        pyTreeFoam.openFolderNautilus(solveCaseFix)
        event.Skip()

    #dataSetClear
    def onDataSetClear(self, event): # wxGlade: MyFrame.<event_handler>
        self.selDataSetClear(event)
        event.Skip()

    #runCAD
    def onRunCAD(self, event): # wxGlade: MyFrame.<event_handler>
        self.selRunCAD(event)
        event.Skip()

    #caseOpen
    def onCaseOpen(self, event): # wxGlade: MyFrame.<event_handler>
        self.onFolderOpen(event)
        event.Skip()

    #editControlDict
    def onEditControlDict(self, event):  # wxGlade: MyFrame.<event_handler>
        self.onCntDictOpen(event)

    #controlDictOpen
    def onCntDictOpen(self, event): # wxGlade: MyFrame.<event_handler>
        global solveCaseFix
        if self.checkFolderMsg(solveCaseFix) == "case":
            openFiles = solveCaseFix + "/system/controlDict "
            openFiles += solveCaseFix + "/system/fvSchemes "
            openFiles += solveCaseFix + "/system/fvSolution"
            pyTreeFoam.runEditor(openFiles)

    #timeFolderの変更時
    def onChangeTime(self, event):  # wxGlade: MyFrame.<event_handler>
        global solveCaseFix
        if self.checkFolderMsg(solveCaseFix) == "case":
            self.changeTimeFolder(solveCaseFix)

    #stopAtの変更時
    def onChangeStopAt(self, event):  # wxGlade: MyFrame.<event_handler>
        global solveCaseFix
        if self.checkFolderMsg(solveCaseFix) == "case":
            self.changeStopAt(solveCaseFix)

    def onShowToolTip(self, event):
        self.showHideToolTip(event)
        event.Skip()

    #keyEvent
    def onKeyEvent(self, event):
        code = event.GetKeyCode()
        print "code=", code
        #event.Skip()


    #  noNumFolderMsg
    #    timeFolderが無い事のメッセージを表示
    def noNumFolderMsg(self):
        title = _(u"エラー")
        mess = _(u"編集するtimeFolderがありません")
        self.errDialog(title, mess)


    #--------event menu ---------------------
    #folder選択時（ダブルクリック時）
    def onItemActivated(self, event): # wxGlade: MyFrame.<event_handler>
        global folderMsg
        pos = event.GetPoint()
        colWidth = [self.tree_ctrl_1.GetColumnWidth(0),
                    self.tree_ctrl_1.GetColumnWidth(1),
                    self.tree_ctrl_1.GetColumnWidth(2),
                    self.tree_ctrl_1.GetColumnWidth(3),
                    self.tree_ctrl_1.GetColumnWidth(4),
                    self.tree_ctrl_1.GetColumnWidth(5)]
        folderMsg = "no"
        item = self.tree_ctrl_1.GetSelection()
        selectDir = self.getDirectory(item)
        #name = self.tree_ctrl_1.GetItemText(item)
        name = self.getTreeNameFromItem(item)
        i=0
        itemP = item
        while name != "":
            itemP = self.tree_ctrl_1.GetItemParent(itemP)
            name = self.getTreeNameFromItem(itemP)
            """
            try:
                name = self.tree_ctrl_1.GetItemText(itemP)
            except:
                name = ""
            """
            i += 1
        if pos[0] <= (i+1)*16:
            #folderIcon Dクリック時:解析caseとして設定
            self.changeSolveCase(item)
        elif pos[0] <= colWidth[0]:
            #folder Dクリック時:folderOpen
            self.onItemOpen(event)
        elif pos[0] <= colWidth[0] + 16:
            #solverIcon Dクリック時:解析caseとして設定
            if self.checkFolderMsg(selectDir) == "case":
                self.changeSolveCase(item)
        elif pos[0] <= colWidth[0] + colWidth[1]:
            #solverName Dクリック時:controlDictをopen
            if self.checkFolderMsg(selectDir) == "case":
                if selectDir != solveCaseFix:
                    if self.isSolveCase(selectDir) == "OK":
                        self.changeSolveCase(item)
                        self.onCntDictOpen(event)
                else:
                    self.onCntDictOpen(event)
        elif pos[0] <= colWidth[0]+colWidth[1]+colWidth[2]+colWidth[3]+colWidth[4]+colWidth[5]:
            #nR Dクリック時:paraFoam起動
            if self.checkFolderMsg(selectDir) == "case":
                if selectDir != solveCaseFix:
                    if self.isSolveCase(selectDir) == "OK":
                        self.changeSolveCase(item)
                        self.onRunParaFoam(event)
                else:
                    self.onRunParaFoam(event)


    def isSolveCase(self, selectDir):
        title = _(u"解析Caseの確認")
        message = _(u"選択したcaseは、解析caseとして設定されていません。\n  解析caseとして設定しますか？")
        ans = self.okCancelDialog(title, message)
        return ans
        

    #folderTree縮小時
    def onItemCollapsed(self, event): # wxGlade: MyFrame.<event_handler>
        collItem = event.GetItem()
        rootItem = self.tree_ctrl_1.GetRootItem()
        selItem = self.tree_ctrl_1.GetSelection()
        if collItem == rootItem:
            self.tree_ctrl_1.SelectItem(rootItem, rootItem, True)
        if selItem == rootItem:
            parent = rootItem
        else:
            parent = self.tree_ctrl_1.GetItemParent(selItem)
        while parent != rootItem:
            if parent == collItem:
                self.tree_ctrl_1.SelectItem(parent, parent, True)
                break
            parent = self.tree_ctrl_1.GetItemParent(parent)
        #self.tree_ctrl_1.ScrollTo(collItem)
        #孫item削除
        self.delGrandChildrenItem(collItem)
        self.clearStatus()
        self.setBackgroundColour()
        event.Skip()

    #folderTree展開時
    def onItemExpanded(self, event): # wxGlade: MyFrame.<event_handler>
        self.writeStatus(_(u"childrenItemsを展開中..."))
        parent = event.GetItem()
        #parentの子itemのイメージをセット
        self.setChildrenImage(parent)
        #parentの子itemに解析caseあればimageをセット
        self.setChildrenImageSolveCase(parent)
        #parentの孫itemを追加（孫が
        self.addGrandChildren(parent)
        #子itemを折りたたむ
        self.collapseChildren(parent)
        self.clearStatus()
        self.setBackgroundColour()
        event.Skip()

    #folder選択時
    def onSelChanged(self, event):
        global selectTreeDir
        #textCtrl内のlog（オーバ分）を削除
        self.delTextLog()
        #item選択時の処理
        item = self.tree_ctrl_1.GetSelection()
        selectDir = self.getDirectory(item)
        selectTreeDir = selectDir
        checkResult = checkFolder(selectDir)
        if (checkResult == "case"):
            [solver, BC] = getSolverBC(selectDir)
            nRst = getNumberResult(selectDir)
            self.setItemOFImage(item, solver, nRst, BC)
            if selectDir == solveCaseFix:
                self.setSolverInLabel(solver)
                self.tree_ctrl_1.SetItemImage(item, self.solveCaseidx, 0,
                    wx.TreeItemIcon_Normal)
                self.setEditTimeFolder(solveCaseFix)
                self.setSolverStopTime(solveCaseFix)
        elif checkResult == "salome":
            if selectDir == solveCaseFix:
                self.tree_ctrl_1.SetItemImage(item, self.salomeCheckidx, 0,
                    wx.TreeItemIcon_Normal)
        else:
            #folderを解析caseとしている場合
            if selectDir == solveCaseFix:
                self.tree_ctrl_1.SetItemImage(item, self.folderCheckidx, 0,
                    wx.TreeItemIcon_Normal)
                self.setEditTimeFolder(solveCaseFix)
                self.setSolverStopTime(solveCaseFix)
        self.saveSelCaseDirToConfig(selectDir)            #selectDirを保存
        self.clearStatus()
        event.Skip()

    def onItemOpen(self, event):
        print _(u"フォルダをopenします。")
        item = self.tree_ctrl_1.GetSelection()
        directory = self.getDirectory(item)
        pyTreeFoam.openFolderNautilus(directory)

    #windowClose時
    def onCloseWindow(self, event):
        treeSize = self.GetSize()
        colWidth = [self.tree_ctrl_1.GetColumnWidth(0),
                    self.tree_ctrl_1.GetColumnWidth(1),
                    self.tree_ctrl_1.GetColumnWidth(2),
                    self.tree_ctrl_1.GetColumnWidth(3),
                    self.tree_ctrl_1.GetColumnWidth(4),
                    self.tree_ctrl_1.GetColumnWidth(5)]
        if self.window_1.IsSplit() == True:
            splitWidth = self.window_1.GetSashPosition()
        else:
            splitWidth = -1
        try:
            self.writeConfig()
            endingTreeFoam(treeSize, colWidth, splitWidth)
        except:
            title = _(u"エラー")
            message = _(u"書込エラーが発生しました。\n  強制終了します。")
            self.errDialog(title, message)
        self.Destroy()
        #systemClipBoard使用の為、終了処理追加
        #gtk.main_quit()
        return False

    #toolTipの表示
    def showHideToolTip(self, event):
        global toolTipText, selCaseDirFix
        (x,y)=event.GetPositionTuple()
        (item, a, flag) = self.tree_ctrl_1.HitTest((x,y))
        currDir = self.getDirectory(item)
        if currDir == selCaseDirFix:
            folder = checkFolder(selCaseDirFix)
            colW = [self.tree_ctrl_1.GetColumnWidth(0),
                    self.tree_ctrl_1.GetColumnWidth(1),
                    self.tree_ctrl_1.GetColumnWidth(2),
                    self.tree_ctrl_1.GetColumnWidth(3),
                    self.tree_ctrl_1.GetColumnWidth(4)]
            #name = self.tree_ctrl_1.GetItemText(item)
            name = self.getTreeNameFromItem(item)
            i = len(currDir.split("/"))
            if x <= (i+1)*16:
                #解析caseとして設定
                toolTipText = _(u"ここをダブルクリックすると、\n  解析caseとして設定します。")
            elif x <= colW[0]:
                #folderOpen
                toolTipText = _(u"ここをダブルクリックすると、\n  folderを開きます。")
            elif x<= colW[0] + 16 and folder == "case":
                #解析caseとして設定（solverIcon)
                toolTipText = _(u"ここをダブルクリックすると、\n  解析caseとして設定します。")
            elif x<= colW[0]+colW[1] and folder == "case":
                #controlDictOpen
                toolTipText = _(u"ここをダブルクリックすると、\n  controlDictを開きます。")
            elif x<= colW[0]+colW[1]+colW[2]+colW[3]+colW[4] and folder == "case":
                #paraFoam起動
                toolTipText = _(u"ここをダブルクリックすると、\n  paraFoamを起動します。")
            else:
                toolTipText = u""
            if wx.version().split()[0] < "3.0":
                self.tree_ctrl_1.SetToolTip(wx.ToolTip.Enable(True))
            if toolTipText != u"":
                #self.tree_ctrl_1.SetToolTip(wx.ToolTip(toolTipText))
                self.tree_ctrl_1.SetToolTipString(toolTipText)
            else:
                #self.tree_ctrl_1.SetToolTip(wx.ToolTip.Enable(False))
                self.tree_ctrl_1.SetToolTipString("")
        else:
            if wx.version().split()[0] < "3.0":
                self.tree_ctrl_1.SetToolTip(wx.ToolTip.Enable(False))
            self.tree_ctrl_1.SetToolTipString("")

    #  delTextLog
    #    textCtrl内のオーバするlogを削除
    def delTextLog(self):
        log = self.text_ctrl_1.GetValue()
        if len(log) > 100000:
            newLog = log[-100000:]
            self.text_ctrl_1.SetValue("")
            self.text_ctrl_1.AppendText(newLog)


    #------------Popup menu-------------
    # setPopupMenuItems
    #  ポップアップメニュー項目設定
    def setPopupMenuItems(self):
        menu = [_(u"開く"), _(u"端末の起動"), _(u"解析caseとして設定"),
                "-", _(u"FOAM端末の起動"), _(u"gridEditor起動..."),
                _(u"コピー\tCtrl+C"), _(u"貼り付け\tCtrl+V"),
                _(u"caseの貼り付け\tCtrl+B"),
                "-", _(u"フォルダ名変更..."), _(u"新しいフォルダ追加"),
                _(u"フォルダ削除..."),
                "-",_(u"loginシェル起動"), _(u"sshfsサーバ マウント"),
                _(u"sshfsサーバ アンマウント"), _(u"貼り付け(scp圧縮転送,cp)"),
                "-", _(u"CADの起動"), _(u"SalomeMecaの起動")]
        return menu

    def setPopupMenuItemsSolver(self):
        menu = [_(u"開く"), "-", _(u"FOAM端末の起動"),
                _(u"gridEditor起動..."), _(u"fieldの編集..."),
                _(u"fieldにデータセット..."),
                _(u"controlDictの編集"), _(u"properties(const)の編集..."),
                _(u"dictionaries(sys)の編集..."), _(u"meshの編集..."),
                "-", _(u"solver実行"), _(u"plotWatcherを実行"), _(u"並列処理...")]
        return menu

    def setPopupMenuItemsNotSolveCase(self):
        menu = [_(u"開く"), _(u"端末の起動"), _(u"解析caseとして設定"),
                "-", _(u"FOAM端末の起動"), _(u"gridEditor起動...")]
        return menu

    def setPopupMenuItemsResult(self):
        menu = [_(u"開く"), "-", _(u"FOAM端末の起動"),
                _(u"gridEditor起動..."), _(u"残渣の確認(plotWatches起動)"),
                _(u"結果フォルダの削除...")]
        return menu



    #
    # OnShowPopup
    #  ポップアップメニュー表示
    def OnShowPopup(self, event):
        global folderMsg
        item = event.GetItem()
        #self.tree_ctrl_1.SelectItem(item, item, True)
        #self.onItemActivated(event)
        pos = event.GetPoint()
        colWidth = [self.tree_ctrl_1.GetColumnWidth(0),
                    self.tree_ctrl_1.GetColumnWidth(1),
                    self.tree_ctrl_1.GetColumnWidth(2),
                    self.tree_ctrl_1.GetColumnWidth(3),
                    self.tree_ctrl_1.GetColumnWidth(4)]
        folderMsg = "no"
        item = self.tree_ctrl_1.GetSelection()
        selectDir = self.getDirectory(item)
        if pos[0] <= colWidth[0]:
            self.tree_ctrl_1.PopupMenu(self.popupmenu, pos)
        elif pos[0] <= colWidth[0] + colWidth[1]:
            if self.checkFolderMsg(selectDir) == "case":
                if selectDir == solveCaseFix:
                    self.tree_ctrl_1.PopupMenu(self.popupmenuSolver, pos)
                else:
                    self.tree_ctrl_1.PopupMenu(self.popupmenuNotSolveCase, pos)
        elif pos[0] <= colWidth[0]+colWidth[1]+colWidth[2]+colWidth[3]+colWidth[4]:
            if self.checkFolderMsg(selectDir) == "case":
                if selectDir == solveCaseFix:
                    self.tree_ctrl_1.PopupMenu(self.popupmenuResult, pos)
                else:
                    self.tree_ctrl_1.PopupMenu(self.popupmenuNotSolveCase, pos)
        folderMsg = "yes"
        return


    #folderのpopupメニュー----------------------
    def OnPopupItemSelected(self, event):
        global selCaseDir, solveCaseFix, editName, childrenList, rootDir
        PPitem = self.popupmenu.FindItemById(event.GetId())
        text = PPitem.GetText()
        #開く
        if (text == _(u"開く")):
            items = self.tree_ctrl_1.GetSelections()
            for item in items:
                directory = self.getDirectory(item)
                pyTreeFoam.openFolderNautilus(directory)
        #端末の起動
        elif (text == _(u"端末の起動")):
            self.runTerms()
        #FOAM端末の起動
        elif (text == _(u"FOAM端末の起動")):
            self.runFoamTerms()
        #gridEditor起動
        elif (text == _(u"gridEditor起動...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                #self.changeSolveCase(item)
                selCaseDir = self.getDirectory(item)
                self.openGridEditor(selCaseDir)
        #解析caseとして設定
        elif (text == _(u"解析caseとして設定")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
        #新しいフォルダ追加
        elif (text == _(u"新しいフォルダ追加")):
            if self.checkMultiSelection(text)==False:
                self.insertFolder()
        #フォルダ削除
        elif (text == _(u"フォルダ削除...")):
            self.deleteFolders()
        #フォルダ名修正
        elif (text == _(u"フォルダ名変更...")):
            if self.checkMultiSelection(text)==False:
                self.renameFolder()
        #フォルダコピー
        elif (text == _(u"コピー") or text == _(u"コピー\tCtrl+C")):
            self.foldersCopy()
        #caseのコピー
        #elif (text == _(u"caseのコピー")):
        #    self.casesCopy()
        #貼付け
        elif (text == _(u"貼り付け") or text == _(u"貼り付け\tCtrl+V")):
            if self.checkMultiSelection(text)==False:
                self.foldersPaste()
        #case貼り付け
        elif (text == _(u"caseの貼り付け") or text == _(u"caseの貼り付け\tCtrl+B")):
            if self.checkMultiSelection(text)==False:
                self.casesPaste()
        #loginシェル起動
        elif (text == _(u"loginシェル起動")):
            if self.checkMultiSelection(text)==False:
                self.runLoginShell()            
        #sshfsによるサーバマウント
        elif (text == _(u"sshfsサーバ マウント")):
            if self.checkMultiSelection(text)==False:
                self.sshfsServerMount()
        #サーバアンマウント
        elif (text == _(u"sshfsサーバ アンマウント")):
            if self.checkMultiSelection(text)==False:
                self.sshfsServerUnmount()
        #貼り付け(scp圧縮転送,cp)
        elif (text == _(u"貼り付け(scp圧縮転送,cp)")):
            if self.checkMultiSelection(text)==False:
                self.pasteScpCompTransfer()
        #CADの起動
        elif (text == _(u"CADの起動")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                caseDir = self.getDirectory(item)
                #self.selRunCAD(event)
                self.runCAD(caseDir)
        #SalomeMecaの起動
        elif (text == _(u"SalomeMecaの起動")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                caseDir = self.getDirectory(item)
                #self.selRunSalome(event)
                self.runSalomeMeca(caseDir)

    #solverのpopupメニュー ---------------------------
    def OnPopupItemSolverSelected(self, event):
        global selCaseDir, solveCaseFix, editName, childrenList, rootDir
        PPitem = self.popupmenuSolver.FindItemById(event.GetId())
        text = PPitem.GetText()
        #開く
        if (text == _(u"開く")):
            items = self.tree_ctrl_1.GetSelections()
            for item in items:
                directory = self.getDirectory(item)
                pyTreeFoam.openFolderNautilus(directory)
        #FOAM端末の起動
        elif (text == _(u"FOAM端末の起動")):
            if self.checkMultiSelection(text)==False:
                self.runFoamTerms()
        #gridEditor起動
        elif (text == _(u"gridEditor起動...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                caseDir = self.getDirectory(item)
                self.openGridEditor(caseDir)
        #fieldの編集
        elif (text == _(u"fieldの編集...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                caseDir = self.getDirectory(item)
                self.selEditField(event)
        #fieldにデータセット
        elif (text == _(u"fieldにデータセット...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                caseDir = self.getDirectory(item)
                self.selDataSetClear(event)
        #controlDict, fvの編集
        elif (text == _(u"controlDictの編集")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.onCntDictOpen(event)
        #propertiesの編集
        elif (text == _(u"properties(const)の編集...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.editPropertiesFiles()
        #dictionariesの編集
        elif (text == _(u"dictionaries(sys)の編集...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.editDict()
        #meshの編集
        elif (text == _(u"meshの編集...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.selEditMesh(event)
        #solver実行
        elif (text == _(u"solver実行")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.selRunSolver(event)
        #plotWatcherを実行
        elif (text == _(u"plotWatcherを実行")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.runPlotWatcher()

        #並列処理
        elif (text == _(u"並列処理...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.onParallel(event)

    #resultのpopupメニュー --------------------
    def OnPopupItemResultSelected(self, event):
        global selCaseDir, solveCaseFix, editName, childrenList, rootDir
        PPitem = self.popupmenuResult.FindItemById(event.GetId())
        text = PPitem.GetText()
        #開く
        if (text == _(u"開く")):
            items = self.tree_ctrl_1.GetSelections()
            for item in items:
                directory = self.getDirectory(item)
                pyTreeFoam.openFolderNautilus(directory)
        #FOAM端末の起動
        elif (text == _(u"FOAM端末の起動")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                caseDir = self.getDirectory(item)
                self.runFoamTerms()
        #gridEditor起動
        elif (text == _(u"gridEditor起動...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                caseDir = self.getDirectory(item)
                self.openGridEditor(caseDir)

        #残渣の確認(plotWatcher起動)
        elif (text == _(u"残渣の確認(plotWatches起動)")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.runPlotWatcher()
            
        #結果フォルダの削除
        elif (text == _(u"結果フォルダの削除...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
                self.deleteResultFolders()
                self.reloadItems()

    #NotSolveCaseのpopupメニュー --------------------
    def OnPopupItemNotSolveCaseSelected(self, event):
        global selCaseDir, solveCaseFix, editName, childrenList, rootDir
        PPitem = self.popupmenuNotSolveCase.FindItemById(event.GetId())
        text = PPitem.GetText()
        #開く
        if (text == _(u"開く")):
            items = self.tree_ctrl_1.GetSelections()
            for item in items:
                directory = self.getDirectory(item)
                pyTreeFoam.openFolderNautilus(directory)
        #端末の起動
        elif (text == _(u"端末の起動")):
            self.runTerms()
        #解析caseとして設定
        elif (text == _(u"解析caseとして設定")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                self.changeSolveCase(item)
        #FOAM端末の起動
        elif (text == _(u"FOAM端末の起動")):
            self.runFoamTerms()
        #gridEditor起動
        elif (text == _(u"gridEditor起動...")):
            if self.checkMultiSelection(text)==False:
                item = self.tree_ctrl_1.GetSelection()
                #self.changeSolveCase(item)
                selCaseDir = self.getDirectory(item)
                self.openGridEditor(selCaseDir)


    def checkMultiSelection(self, text):
        items = self.tree_ctrl_1.GetSelections()
        if len(items) == 1:
            return False
        else:
            self.errorMultiSelect(text)
            return True

    def errorMultiSelect(self, name):
        title = _(u"エラー")
        msg = _(u"複数行選択しています。\n「") + name + _(u"」は複数行選択できません。")
        self.errDialog(title, msg)

    #case作成、修正
    def createAndChangeCase(self):
        comm  = "cd " + solveCaseFix + ";"
        comm += "createAndChangeCaseDialog.py &"
        os.system(comm)

    #setMultiRegion
    def setMultiRegion(self, event):
        comm  = "cd " + solveCaseFix + ";"
        comm += "setMultiRegionDialog.py &"
        os.system(comm)

    def runEditMesh(self):
        global solveCaseFix
        comm  = "cd " + solveCaseFix + ";"
        comm += "meshOperationDialog.py &"
        pyTreeFoam.runCommand(comm)

    def runTopoSetEditor(self):
        global solveCaseFix, OFversionFix
        OFversion = OFversionFix
        if OFversion >= "2.0.0":
            caseDir = solveCaseFix
            items = getHelyxosData(caseDir)
            stlDir = items[0]
            comm = "cd " + caseDir + ";" 
            comm += "topoSetEditor.py " + caseDir + " " + stlDir + " &"
            pyTreeFoam.runCommand(comm)
        else:
            title = _(u"エラー")
            message = _(u"OpenFOAM-") + OFversion + _(u" ではTopoSetEditorは使えません\n")
            message += _(u"OpenFOAM-2.0.0 以降で使用できます。")
            self.errDialog(title, message)

    #caseの初期化
    def caseInitialize(self):

        def isTime(name):
            try:
                a=float(name)
                flag = True
            except:
                flag = False
            return flag

        global solveCaseFix
        #singleCore計算時の処理
        timeFolders = pyTreeFoam.getTimeFolders(solveCaseFix)
        ans = ""
        ansFlag = 0
        [folders, files] = pyTreeFoam.getFoldersFiles(solveCaseFix)
        [need, unneed] = pyTreeFoam.selectNeedFiles(files)
        [needFolders, unneedFolders] = pyTreeFoam.selectNeedFolders(folders)
        #削除対象のfileがあるか
        if len(timeFolders) > 1 or len(unneed) > 0 or len(unneedFolders) > 0:
            title = _(u"caseの初期化")
            msg = _(u"計算結果や不要なファイルを削除して、caseを初期化します。")
            ans = self.okCancelDialog(title, msg)
            if ans == "OK":
                if selCaseDirFix != solveCaseFix:
                    msg = _(u"解析caseと選択しているcaseが異なっています。\n　解析caseを初期化しますか？")
                    ans = self.okCancelDialog(title, msg)
                    if ans == "OK":
                        ansFlag = 1
                else:
                    ansFlag = 1
                if ansFlag == 1:
                    #不要なfolderをゴミ箱へ（processor, timeFolderは削除）
                    for name in unneedFolders:
                        if name[:9] == "processor" or isTime(name) == True:
                            comm = "rm -rf " + solveCaseFix + "/" + name
                            os.system(comm)
                        else:
                            delName = solveCaseFix + "/" + name
                            self.deleteFolder(delName)
                    #不要なfileをゴミ箱へ（削除しない）
                    for name in unneed:
                        delName = solveCaseFix + "/" + name
                        self.deleteFolder(delName)
                    mess = _(u"caseを初期化しました。")
                    print mess
                    self.okDialog(title, mess)

    #loginシェル起動
    def runLoginShell(self):
        item = self.tree_ctrl_1.GetSelection()
        getDir = self.getDirectory(item)
        data = pyTreeFoam.readSshfsData()
        hostName = data[0]
        userName = data[1]
        hostDir = data[2]
        mountDir = data[3]
        login = data[4]
        setEnviron = data[5]
        if mountDir == "":
            setEnviron = ""
        else:
            if mountDir == getDir[:len(mountDir)]:
                openDir = "~" + getDir[len(mountDir):]
                lines = setEnviron.split("\n")
                i = len(lines) - 1
                while i >= 0:
                    if lines[i][:len("cd")] == "cd":
                        words = lines[i].split()
                        lines[i] = "cd " + openDir
                        break
                    i -= 1
                setEnviron = "\n".join(lines)
            else:
                setEnviron = ""
        #tempFile作成
        name = "setEnviron"
        fileName = os.getenv("TreeFoamUserPath") + "/temp/" + name
        f=open(fileName, "w"); f.write(setEnviron); f.close()
        #envファイルを転送
        comm = "scp " + fileName + " " + userName + "@" + hostName + ":" + "~/"
        [stat, err] = pyTreeFoam.runCommandErrorCheck(comm)
        #login = "ssh ff01Focus\n"
        f=open(fileName, "w"); f.write(login); f.close()
        comm = "gnome-terminal --geometry=" + foamTermSize + " -x bash --rcfile " + fileName + " &"
        os.system(comm.encode("utf-8"))


    #sshfsによるサーバマウント
    def sshfsServerMount(self):
        global sshfsDir
        self.writeStatus(_(u"サーバ接続中..."))
        item = self.tree_ctrl_1.GetSelection()
        mountDir = self.getDirectory(item)
        files = os.listdir(mountDir)
        if len(files) == 0:
            #サーバをマウント
            data = pyTreeFoam.readSshfsData()
            data[3] = mountDir
            pyTreeFoam.writeSshfsData(data)
            hostName = data[0]
            userName = data[1]
            hostDir = data[2]
            comm = "sshfs " + userName + "@" + hostName + ":" + hostDir
            comm += " " + mountDir
            [stat, errMess] = pyTreeFoam.runCommandErrorCheck(comm)
            if stat == "OK":
                sshfsDir = mountDir
                title = _(u"サーバマウント")
                mess = _(u"サーバをマウントしました。") + "\n"
                mess += "HostName:    " + hostName + "\n"
                mess += "User:        " + userName + "\n"
                mess += "HostDir:     " + hostDir + "\n"
                mess += "MountPoint:  " + mountDir + "\n"
                self.okDialog(title, mess)
            else:
                sshfsDir = ""
                data[3] = ""
                pyTreeFoam.writeSshfsData(data)
                title = _(u"エラー")
                mess = _(u"サーバをマウントできませんでした。") + "\n"
                mess += errMess.decode("utf-8")
                self.errDialog(title, mess)
            self.reloadItems()
            self.clearStatus()
        else:
            flag = 0
            for nameDir in files:
                name = nameDir.split("/")[-1]
                if name == ".bashrc" or name == ".ssh":
                    flag += 1
            if flag == 2:
                title = _(u"警告")
                mess = _(u"既にマウントされています。")
                self.warningDialog(title, mess)
                return
            else:
                title = _(u"エラー")
                mess = _(u"マウントするfolder内にファイルが存在します。") + "\n"
                mess += _(u"マウントできません。")
                self.errDialog(title, mess)

    #sshfsサーバアンマウント
    def sshfsServerUnmount(self):
        global sshfsDir
        self.writeStatus(_(u"サーバ接続中..."))
        item = self.tree_ctrl_1.GetSelection()
        unmountDir = self.getDirectory(item)
        files = os.listdir(unmountDir)
        if len(files) == 0:
            title = _(u"sshfsサーバアンマウント")
            mess = _(u"サーバは、マウントされていません。")
            self.okDialog(title, mess)
            return
        flag = 0
        for name in files:
            if name == ".bashrc" or name == ".ssh":
                flag += 1
        if flag == 2:
            #サーバアンマウント
            title = _(u"sshfsサーバアンマウント")
            mess = _(u"サーバをアンマウントします。")
            stat = self.okCancelDialog(title, mess)
            if stat == "OK":
                comm = "fusermount -u " + unmountDir
                [stat, errMess] = pyTreeFoam.runCommandErrorCheck(comm)
                if stat == "OK":
                    sshfsDir = ""
                    data = pyTreeFoam.readSshfsData()
                    data[3] = ""
                    pyTreeFoam.writeSshfsData(data)
                else:
                    title = _(u"エラー")
                    mess = _(u"サーバをアンマウントできませんでした。") + "\n"
                    mess += errMess
                    self.errDialog(title, mess)
            self.reloadItems()
            self.clearStatus()
            return
        else:
            title = _(u"sshfsサーバアンマウント")
            mess = _(u"サーバがアンマウントできません。") + "\n"
            mess += _(u"folder名を確認してください。")
            self.okDialog(title, mess)
            return

    #貼り付け(scp圧縮転送,cp)
    def pasteScpCompTransfer(self):

        #scp実行
        def runCommand(lines):
            fileName = os.getenv("TreeFoamUserPath") + "/temp/run"
            f=open(fileName, "w")
            for line in lines:
                f.write(line)
            f.close()
            os.system("chmod a+x " + fileName)
            comm = "gnome-terminal -e " + fileName + " &"
            os.system(comm)

        global selCaseDirFix, clipBoard, sshfsDir
        f=open(clipBoard); lines=f.readlines(); f.close()
        files = []
        for line in lines[1:]:
            files.append(line.split()[0])
        #hostを取得
        pasteFolder = "~" + selCaseDirFix[len(sshfsDir):]
        data = pyTreeFoam.readSshfsData()
        hostName = data[0]
        userName = data[1]
        #サーバ内のdirを取得
        copyFiles = []
        for name in files:
            if name[:len(sshfsDir)] == sshfsDir:
                nameDir = "~" + name[len(sshfsDir):]
                copyFiles.append(nameDir)
        if len(copyFiles) == 0:
            if selCaseDirFix[:len(sshfsDir)] == sshfsDir:
                #localからserverにコピー
                copyFiles = files
                lines = ["#!/bin/bash\n"]
                for copyFile in copyFiles:
                    line = "scp -Cr " + copyFile + " " + userName + "@" + hostName + ":" + pasteFolder + "\n"
                    lines.append(line)
                runCommand(lines)
            else:
                title = _(u"エラー")
                mess = _(u"copyFolder, pasteFolderともlocal側の設定です。") + "\n"
                mess += _(u"通常の「貼り付け」で貼り付けてください。")
                self.errDialog(title, mess)
                return
        else:
            if selCaseDirFix[:len(sshfsDir)] != sshfsDir:
                #serverからlocalにコピー
                pasteFolder = selCaseDirFix
                lines = ["#!/bin/bash\n"]
                for copyFile in copyFiles:
                    line = "scp -Cr " + userName + "@" + hostName + ":" + copyFile + " " + pasteFolder + "\n"
                    lines.append(line)
                runCommand(lines)
            else:
                #server内からserver内へコピー
                lines = []
                for copyFile in copyFiles:
                    copyFolder = "/".join(copyFile.split("/")[:-1])
                    if copyFolder == pasteFolder:
                        fileName = copyFile.split("/")[-1]
                        line = "cp -rfv " + copyFile + " " + pasteFolder + "/" + fileName + "_copy"
                    else:
                        line = "cp -rfv " + copyFile + " " + pasteFolder
                    lines.append(line)
                comms = '"' + ";".join(lines) + '"'
                commLine = "ssh " + userName + "@" + hostName + " " +comms
                print commLine
                runCommand(commLine)
                return


    def deleteResultFolders(self):
        global solveCaseFix
        #singleCore計算時の処理
        timeFolders = pyTreeFoam.getTimeFolders(solveCaseFix)
        ans = ""
        ansFlag = 0
        if len(timeFolders) > 1:
            title = _(u"結果フォルダの削除")
            msg = _(u"最小時間のフォルダのみ残し、それ以外をゴミ箱に移動します。")
            ans = self.okCancelDialog(title, msg)
            if ans == "OK":
                if selCaseDirFix != solveCaseFix:
                    msg = _(u"解析caseと選択しているcaseが異なっています。\n　解析caseの結果フォルダを削除しますか？")
                    ans = self.okCancelDialog(title, msg)
                    if ans == "OK":
                        ansFlag = 1
                else:
                    ansFlag = 1
                if ansFlag == 1:
                    i=1
                    while i<len(timeFolders):
                        delDir = solveCaseFix + "/" + timeFolders[i]
                        #self.deleteFolder(delDir)
                        comm = "rm -rf " + delDir
                        os.system(comm)
                        i += 1
        #並列計算時の処理
        [folders, files] = pyTreeFoam.getFoldersFiles(solveCaseFix)
        flag = 0
        ansFlag = 0
        for folder in folders:
            if folder[:len("processor")] == "processor":
                timeFolders = pyTreeFoam.getTimeFolders(solveCaseFix+"/processor0")
                if len(timeFolders) > 1:
                    flag = 1
                break
        if flag == 1:
            if ans == "":
                title = _(u"結果フォルダの削除")
                msg = _(u"最小時間のフォルダのみ残し、それ以外をゴミ箱に移動します。")
                ans = self.okCancelDialog(title, msg)
            if ans == "OK":
                if selCaseDirFix != solveCaseFix:
                    msg = _(u"解析caseと選択しているcaseが異なっています。\n　解析caseの結果フォルダを削除しますか？")
                    ans = self.okCancelDialog(title, msg)
                    if ans == "OK":
                        ansFlag = 1
                else:
                    ansFlag = 1
                if ansFlag == 1:
                    for folder in folders:
                        if folder[:len("processor")] == "processor":
                            delCaseDir = solveCaseFix + "/" + folder
                            timeFolders = pyTreeFoam.getTimeFolders(delCaseDir)
                            i = 1
                            while i<len(timeFolders):
                                delDir = delCaseDir + "/" + timeFolders[i]
                                #self.deleteFolder(delDir)
                                comm = "rm -rf " + delDir
                                os.system(comm)
                                i += 1


    def openGridEditor(self, caseDir):
        timeFolder = getEditTimeFolder(caseDir)
        if timeFolder != "":
            fieldDir = caseDir + "/" + timeFolder
            caseFolder = caseDir.split("/")[-1]
            title = ": " + caseFolder + "/" + timeFolder + "/."
            title = _(u"boundaryFieldの編集")
            mess = _(u"選択された boundaryField を編集します")
            comm  = "openGridEditorDialog.py " + nTreeFoam + " '" + title
            comm += "' '" + mess + "' " + fieldDir + " " + timeFolder + " &"
            os.system(comm.encode("utf-8"))
        else:
            title = _(u"エラー")
            mess = _(u"OpenFOAMのCaseフォルダではありません！")
            self.errDialog(title, mess)


    def editPropertiesFiles(self):
        global solveCaseFix
        wdir = solveCaseFix + "/constant"
        [folders, files] = pyTreeFoam.getFoldersFiles(wdir)
        if len(folders) >= 1:
            title = _(u"...Properties File の編集")
            img = "oneFile"
            mess = _(u"編集する Properties file を選択してください。\n\nProperties File は、constant フォルダ内にあります。")
            editDir = wdir
            job = "editProperties"
            # properties File の選択と編集
            self.showSelectFolderFilesDialog(job, title, img, mess, editDir)
        else:
            print _(u"constantフォルダ内にpolyMeshフォルダがありません!\n  current directoryを確認してください。")


    def editDict(self):
        global solveCaseFix
        wdir = solveCaseFix + "/system"
        title = _(u"Dict File の編集")
        img = "oneFaile"
        mess = _(u"編集するDict file を選択してください。\n\nDict file は、systemフォルダ内にあります。")
        editDir = wdir
        job = "editDictFile"
        # boundary File の選択と編集
        self.showSelectFolderFilesDialog(job, title, img, mess, editDir)

    def showSelectFolderFilesDialog(self, job, title, img, mess, editDir):
        comm  = "selectFolderFilesDialog.py " + job + " '" + title + "' " + img
        comm += " '" + mess + "' " + editDir + " &"
        os.system(comm.encode("utf-8"))

    def deleteFolders(self):
        global selCaseDir, solveCaseFix
        print _(u"フォルダを削除します")
        self.writeStatus(_(u"フォルダを削除中..."))
        items = self.tree_ctrl_1.GetSelections()
        for item in items:
            ans = self.checkDelete(item)
            if len(ans) != 0:
                break
        if len(ans) != 0:
            title = _(u"エラー")
            self.errDialog(title, ans)
            return

        title = _(u"フォルダの削除")
        mess = _(u"フォルダをゴミ箱へ移動します")
        ans = self.okCancelDialog(title, mess)
        if ans != "OK":
            return

        for item in items:
            delDir = self.getDirectory(item)
            error = self.deleteFolder(delDir)
            if error != "":
                title = _(u"エラー")
                result = self.okCancelDialog(title, error)
                if result != "OK":
                    break
        selCaseDir = "/".join(delDir.split("/")[:-1])
        #Tree表示に削除を反映
        self.setSelectCase(self.convDirToList(selCaseDir))
        self.reloadItems()
        #selectCaseを設定
        parentDir = selCaseDir
        parentItem = self.getItem(parentDir)
        childrenItems = self.getChildrenItems(parentItem)
        if len(childrenItems) != 0:
            selCaseDir = self.getDirectory(childrenItems[0])
        self.saveSelCaseDirToConfig(selCaseDir)
        self.setSelectCase(self.convDirToList(selCaseDir))
        self.clearStatus()


    def checkDelete(self, item):
        delDir = self.getDirectory(item)
        mess = ""
        if delDir == rootDirFix:
            mess = _(u"rootDirを削除しようとしています。\nrootDirは、削除できません。")
            return mess
        if delDir == solveCaseFix:
            mess = _(u"解析caseを削除しようとしています。\n解析caseは、削除できません。\n削除する場合は、解析caseを変更してください。")
            return mess
        if len(solveCaseFix) > len(delDir):
            for (root, dirs, files) in os.walk(delDir):
                for name in files:
                    if root[:len(solveCaseFix)] == solveCaseFix:
                        mess = _(u"削除するfolder内に解析case解析caseが含まれます。\n解析caseは、削除できません。\n削除する場合は、解析caseを変更してください。")
                        return mess
        return mess


    def deleteFolder(self, delDir):
        mess = ""
        try:
            #ファイルをゴミ箱へ移動
            obj = gio.File(delDir.encode("utf-8"))
            obj.trash()
            #shutil.rmtree(delDir)
        except:
            mess = _(u"「") + delDir + _(u"」フォルダが削除できませんでした。\n　継続しますか？")
            print mess
        return mess


    def insertFolder(self):
        print _(u"フォルダを追加します")
        self.writeStatus(_(u"フォルダを作成中..."))
        item = self.tree_ctrl_1.GetSelection()
        itemDir = self.getDirectory(item)
        folderName = itemDir + "/newFolder"
        n = 0
        error = "NG"
        while error == "NG":
            newFolderName = folderName + "_" + str(n)
            try:
                os.mkdir(newFolderName)
                error = "OK"
            except:
                n += 1
        self.saveSelCaseDirToConfig(newFolderName)
        self.reloadItems()
        newItem = self.getItem(newFolderName)
        self.tree_ctrl_1.SelectItem(newItem, newItem, True)
        self.renameFolder()


    def renameFolder(self):
        global selCaseDir, solveCaseFix, editName, childrenList, rootDir
        self.writeStatus(_(u"フォルダ名を変更中..."))
        item = self.tree_ctrl_1.GetSelection()
        saveDir = self.getDirectory(item)
        saveCaseItem = self.getItem(solveCaseFix)
        #editName = self.tree_ctrl_1.GetItemText(item)
        editName = self.getTreeNameFromItem(item)
        if editName == rootDir:
            self.changeRoot(editName)
        else:
            parent = self.tree_ctrl_1.GetItemParent(item)
            childrenList = self.getChildrenList(parent)
            #self.tree_ctrl_1.EditLabel(item)
            inputTextDDialog.title = _(u"folder名の変更")
            inputTextDDialog.message = _(u"変更するfolder名を入力してください。")
            inputTextDDialog.inputText = editName
            dialog = inputTextDDialog.MyDialog(None)
            result = dialog.ShowModal()
            if inputTextDDialog.status == "OK":
                text = inputTextDDialog.inputText
            else:
                text = u""
            if text != u"":
                flag = 0
                for name in childrenList:
                    if name == text:
                        if name != editName:
                            msg = _(u"フォルダ内に同じ名前があります。")
                            self.errDialog(_(u"エラー"), msg)
                        flag = 1
                        break
                if flag == 0:
                    self.tree_ctrl_1.SetItemText(item, text)
                    parentDir = self.getDirectory(parent)
                    editDir = parentDir + "/" + editName
                    textDir = parentDir + "/" + text
                    shutil.move(editDir, textDir)
                    selCaseDir = textDir
                    self.saveSelCaseDirToConfig(selCaseDir)
                    solveCaseFix = self.getDirectory(saveCaseItem)
                    if saveDir == solveCaseFix:
                        #変更するfolderが解析caseの場合
                        solveCaseFix = textDir
                        #caseName, solverをlabelにセット
                        caseItem = self.getItem(solveCaseFix)
                        self.changeSolveCase(caseItem)
                    self.saveSelCaseDirToConfig(selCaseDir)
                    self.reloadItems()
                    self.checkLinkAtGauge(parentDir, editDir, textDir)
        self.clearStatus()


    def checkLinkAtGauge(self, checkDir, oldDir, newDir):
        gaugeDDialog.job = "checkLink"
        gaugeDDialog.title = _(u"親folder以下のlinkをチェック中")
        gaugeDDialog.checkDir = checkDir
        gaugeDDialog.oldDir = oldDir
        gaugeDDialog.newDir = newDir
        dialog = gaugeDDialog.MyDialog(None)
        result = dialog.ShowModal()
        ans = gaugeDDialog.status
        if ans != "OK":
            #キャンセルした場合
            title = _(u"linkのチェック、修正")
            mess = _(u"linkのチェックをキャンセルしました。")
            self.okDialog(title, mess)
        return


    #  foldersCopy
    #    folderのコピー
    def foldersCopy(self):
        global clipBoard
        items = self.tree_ctrl_1.GetSelections()
        f = open(clipBoard, "w")
        f.write("foldersCopy\n")
        for item in items:
            directory = self.getDirectory(item)
            print "copy--->", directory
            f.write(directory.encode("utf-8") + "\n")
        f.close()
        #systemClipBoardへコピー
        comm = "copyToSystemClipBoard.py " + clipBoard + " &"
        os.system(comm)


    def checkCaseDir(self, caseDir):
        ans = [[],[]]               #ans=[[dirs], [files]]
        noans = [[],[]]
        [folders, files] = pyTreeFoam.getFoldersFiles(caseDir)
        caseFolder = []
        for folder in folders:
            if checkFolder(caseDir + "/" + folder) != "case":
                caseFolder.append(folder)
        [needFolders, unneedFolders] = pyTreeFoam.selectNeedFolders(caseFolder)
        nFolders = 0
        for name in needFolders:
            if name == "system" or name == "constant":
                nFolders += 1
            ans[0].append(caseDir + "/" + name)
        if nFolders != 2:
            return noans        
        [needFiles, unneedFiles] = pyTreeFoam.selectNeedFiles(files)
        for name in needFiles:
            ans[1].append(caseDir + "/" + name)
        return ans


    #----------- system clipBoard を使用 ------------------------------
    #  casesPaste
    #    caseの貼り付け（treefoamClipboardから）
    def casesPaste(self):
        global clipBoard

        #  casesPaste_sub
        #    TreeFoamのclipBoardへ書き込み
        def casesPaste_sub(files, itemDir):
            f = open(clipBoard, "w")
            #casesCopy行作成
            line = "casesCopy " + " ".join(files) + "\n"
            f.write(line)
            #copyList作成
            for caseDir in files:
                [copyDirs, copyFiles] = self.checkCaseDir(caseDir)
                if len(copyDirs) != 0:
                    allCopyFiles = copyDirs + copyFiles
                    for name in allCopyFiles:
                        f.write(name.encode("utf-8") + "\n")
                else:
                    title = _(u"エラー")
                    msg = _(u"「") + caseDir + _(u"」は、OpenFoamのcaseDirectoryではありません。\ncaseコピーできません。")
                    print msg
                    self.errDialog(title, msg)
            f.close()

        #clipBoard取得
        item = self.tree_ctrl_1.GetSelection()
        itemDir = self.getDirectory(item)
        #sysClipboard.request_contents("x-special/gnome-copied-files", callback)
        #pasteContFile = os.getenv("TreeFoamPath") + "/pasteNames"
        pasteContFile = os.getenv("TreeFoamUserPath") + "/data/pasteNames"
        comm = "pasteFromSystemClipBoard.py " + pasteContFile
        os.system(comm)
        #pasteFilesを取得
        #f=open(pasteContFile); cont=f.read(); f.close()
        f=codecs.open(pasteContFile, "r", "utf-8"); cont=f.read(); f.close()
        files = cont.split()
        casesPaste_sub(files, itemDir)

        #casesPaste実行
        f = open(clipBoard); contents = f.read(); f.close()
        lines = contents.decode("utf-8").split("\n")[:-1]   #最後に空文が入るので最後を削除
        copyCont = lines[0].split()
        if copyCont[0] == "casesCopy":
            caseDirs = copyCont[1:]
            copyDirs = lines[1:]
        else:
            title = _(u"エラー")
            msg = _(u"クリップボードのデータは、貼り付ける事ができません。")
            self.errDialog(title, msg)
            return

        #貼付け場所（dir）を取得
        item = self.tree_ctrl_1.GetSelection()
        itemDir = self.getDirectory(item)

        #貼付け名のチェック
        newDirs = []
        caseName = ""
        for copyDir in copyDirs:
            for caseDir in caseDirs:
                if caseDir == copyDir[:len(caseDir)]:
                    #case名のチェック
                    newCaseDir = self.checkCopyDirFile(itemDir, caseDir)
                    if len(newCaseDir) != 0:
                        newDir = newCaseDir + copyDir[len(caseDir):]
                        newDirs.append(newDir)
                    break
        #貼付け
        if len(newDirs) != 0:
            self.pasteFoldersFilesAtGauge(copyDirs, newDirs)

            self.reloadItems()
            newItem = self.getItem(newCaseDir)
            self.tree_ctrl_1.SelectItem(newItem, newItem, True)
        self.reloadItems()


    #----------- system clipBoard を使用 ------------------------------
    #  foldersPaste
    #    systemClipBoardのdataを貼り付ける
    def foldersPaste(self):
        item = self.tree_ctrl_1.GetSelection()
        itemDir = self.getDirectory(item)
        destination = itemDir
        #pasteContFile = os.getenv("TreeFoamPath") + "/pasteNames"
        pasteContFile = os.getenv("TreeFoamUserPath") + "/data/pasteNames"
        #folderをコピー
        comm = "pasteFromSystemClipBoard.py " + pasteContFile
        os.system(comm)
        #pasteFilesを取得
        f=codecs.open(pasteContFile, "r", "utf-8"); cont=f.read(); f.close()
        #f=open(pasteContFile); cont=f.read(); f.close()
        files = cont.split()
        self.foldersPaste_sub(files, destination)
    #-------------------------------------------------------------------

    #  foldersPaste_sub
    #
    def foldersPaste_sub(self, copyDirs, itemDir):
        newDirs = []
        for copyDir in copyDirs:
            newDir = self.checkCopyDirFile(itemDir, copyDir)
            if len(newDir) != 0:
                newDirs.append(newDir)
        if len(newDirs) != 0:
            self.pasteFoldersFilesAtGauge(copyDirs, newDirs)
            self.reloadItems()
            newItem = self.getItem(newDirs[-1])
            self.tree_ctrl_1.SelectItem(newItem, newItem, True)
        self.reloadItems()


    def checkCopyDirFile(self, itemDir, copyDir):
        newDir = itemDir + "/" + copyDir.split("/")[-1]
        if os.path.isdir(copyDir) == True:
            if len(glob.glob(newDir)) == 0:
                return newDir
            else:
                flag = 0
                n = 0
                while (flag == 0 and n < 10):
                    newDir_n = newDir + "_copy" + str(n)
                    if len(glob.glob(newDir_n)) == 0:
                        flag = 1
                    n += 1
                if flag == 1:
                    return newDir_n
                else:
                    return ""
        elif os.path.isfile(copyDir) == True:
            return newDir
        else:
            return ""


    def pasteFoldersFilesAtGauge(self, copyDirs, newDirs):
        gaugeDDialog.job = "copy"
        gaugeDDialog.title = _(u"folder, fileのコピー")
        gaugeDDialog.copyDirs = copyDirs
        gaugeDDialog.newDirs = newDirs
        dialog = gaugeDDialog.MyDialog(None)
        reult = dialog.ShowModal()
        ans = gaugeDDialog.status
        if ans == "NG":
            #コピーをキャンセルした場合
            title = _(u"fileのコピー")
            mess = _(u"コピーを中止しました")
            self.okDialog(title, mess)
        if ans == "ERR":
            #エラーが発生した場合
            title = _(u"エラー")
            [error, mess] = gaugeDDialog.error
            self.errDialog(title, mess)
        return


    def changeConfigTreeFoam(self, event):
        global selCaseDirFix, solveCaseFix
        saveSelCaseDir = selCaseDirFix
        saveSolveCase = solveCaseFix
        #configTreeFoamを書き換え
        #fileName = treeFoamPath + "/" + configFile
        fileName = os.getenv("TreeFoamUserPath") + "/" + configFile
        #comm = "changeConfigTreeFoamDDialog.py " + fileName
        comm = "changeConfigTreeFoamDialog.py " + fileName
        os.system(comm)
        self.readConfig()
        selCaseDirFix = saveSelCaseDir
        solveCaseFix = saveSolveCase
        self.selReload(event)


    def changeRoot(self, editName):
        text = self.textDialog(_(u"rootの変更"), _(u"変更するrootDirを入力してください。"), editName)
        if text != "":
            newName = glob.glob(text)
            if len(newName) == 1:
                self.saveRootDirToConfig(newName[0])
                self.reloadItems()
                msg = _(u"rootDirを変更しました。")
                self.okDialog(_(u"rootDirの変更"), msg)
            else:
                msg = text + _(u" のフォルダは存在しません。")
                self.errDialog(_(u"エラー"), msg)

    def runGridEditor(self, editDir):
        global solveCaseFix
        #title, dirを設定
        caseFolder = editDir.split("/")[-2]
        timeFolder = editDir.split("/")[-1]
        title = ": " + caseFolder + "/" + timeFolder + "/."
        fieldDir = editDir
        if len(glob.glob(fieldDir + "/polyMesh/boundary")) != 0:
            boundaryDir = fieldDir + "/polyMesh"
        else:
            boundaryDir = solveCaseFix + "/constant/polyMesh"
        #Grid表示
        comm = "runGridEditor.py "
        comm+= nTreeFoam + " '" + title + "' " + boundaryDir + " " + fieldDir
        comm+= " &"
        #os.system(comm)
        pyTreeFoam.runOFUtility(comm)

    def runSolver(self, directory):
        global envOpenFOAMFix
        #openFOAM環境でsolver有無チェック
        if self.checkApp(directory, envOpenFOAMFix) == "OK":
            #controlDict内の「runTimeModifiable」をチェック
            if self.checkRunTimeModify(directory) == "NO":
                return
            solver = getSolver(directory)
            if solver != "":
                #dir移動
                saveDir = os.getcwd()
                os.chdir(directory)
                #solve.logのクリア
                f=open("solve.log","w")
                f.close()
                #solverの実行ファイル作成
                caseName = directory.split("/")[-1]
                title =  "#!/bin/bash\n"
                envSet = ". " + envOpenFOAMFix + "\n"
                solverSet = solver + " | tee solve.log\n"
                cont = title + envSet + solverSet
                f=open("run","w")
                f.write(cont)
                f.close()
                #実行権付与
                os.system("chmod a+x run")
                #実行
                comm = "gnome-terminal -t " + caseName + " --geometry=120x20 --zoom=0.9 -x bash --rcfile run &"
                os.system(comm)
                #dirを元に戻す
                os.chdir(saveDir)
            else:
                title = _(u"エラー")
                message = _(u"「controlDict」は、存在しません。\n")
                message = message + _(u"case directory が間違っています。")
                self.errDialog(title, message)
        else:
            title = _(u"エラー")
            message = _(u"環境設定file「bashrcFOAM」が存在しない為、FOAM端末が起動できません。\n")
            message = message + _(u"　　configTreeFoamファイルの内容を確認してください。")
            self.errDialog(title, message)

    def checkRunTimeModify(self, caseDir):
        wdir = caseDir + "/system"
        [runTimeModify] = getFoamContents.controlDict(wdir, ["runTimeModifiable"])
        if runTimeModify == "yes" or runTimeModify == "true" or runTimeModify == "on":
           return "YES"
        else:
            title = _(u"runTimeModifiableのチェック")
            mess = _(u"controlDict内のrunTmeModifiableが「no」になっています。\n")
            mess += _(u"計算中にcontrolDict内の修正ができません。\n")
            mess += _(u"このまま計算を開始しますか？")
            ans = self.yesNoDialog(title, mess)
            return ans 

    def runPlotWatcher(self):
        global solveCaseFix, envOpenFOAMFix
        if self.checkApp(solveCaseFix, envOpenFOAMFix) == "OK":
            solver = getSolver(solveCaseFix)
            if solver != "":
                saveDir = os.getcwd()
                os.chdir(solveCaseFix)
                logFile = "solve.log"
                if len(glob.glob(logFile)) == 0:
                    logFile = "log." + solver
                cont = "#!/ban/bash\n"
                cont = cont + ". " + envOpenFOAMFix + "\n"
                cont = cont + 'echo -n "running plotWatcher"\n'
                cont = cont + "pyFoamPlotWatcher.py " + logFile + " 1> /dev/null 2> /dev/null\n"
                f = open("plotWatcher", "w")
                f.write(cont)
                f.close()
                os.system("chmod a+x plotWatcher")
                title = solveCaseFix
                if len(title) > 30:
                    title = "_..." + title[-30:]
                title = "plotWatcher:" + title
                comm = "gnome-terminal -t " + title + " --geometry=80x2 --hide-menubar -x bash --rcfile plotWatcher"
                os.system(comm)
                os.chdir(saveDir)
            else:
                title = _(u"エラー")
                message = _(u"「controlDict」は、存在しません。\n")
                message = message + _(u"case directory が間違っています。")
                self.errDialog(title, message)
        else:
            title = _(u"エラー")
            message = _(u"環境設定file「bashrcFOAM」が存在しない為、FOAM端末が起動できません。\n")
            message = message + _(u"　　configTreeFoamファイルの内容を確認してください。")
            self.errDialog(title, message)

    def runFoamTerms(self):
        items = self.tree_ctrl_1.GetSelections()
        for item in items:
            directory = self.getDirectory(item)
            self.runFoamTermDir(directory)

    def runFoamTerm(self):
        item = self.tree_ctrl_1.GetSelection()
        directory = self.getDirectory(item)
        self.runFoamTermDir(directory)

    def runFoamTermDir(self, directory):
        global envOpenFOAMFix, foamTermSize, sshfsDir
        if directory[:len(sshfsDir)] == sshfsDir and sshfsDir != "":
            title = _(u"FOAM端末を開く")
            mess = _(u"このdirectoryは、マウントされたものです。") + "\n"
            #mess += _(u"FOAM端末は、openできません。") + "\n"
            mess += _(u"loginシェルを使ってください。") + "\n"
            mess += _(u"ローカルのFOAM端末を開きますか？")
            #self.errDialog(title, mess)
            stat = self.yesNoDialog(title, mess)
            if stat == "NO":
                return

        if self.checkApp(directory, envOpenFOAMFix) == "OK":
            caseName = directory.split("/")[-1]
            comm = "cd " + directory + "; gnome-terminal --geometry=" + foamTermSize + " -t " + caseName + " -x bash --rcfile " + envOpenFOAMFix + " &"
            os.system(comm.encode("utf-8"))
        else:
            title = _(u"エラー")
            message = _(u"「") + envOpenFOAMFix + _(u"」は、存在しません。\n")
            message = message + _(u"FOAM端末の環境設定fileが間違っています。\n")
            message = message + _(u"  configFoamTreeの内容を確認してください。")
            self.errDialog(title, message)

    def runTerms(self):
        items = self.tree_ctrl_1.GetSelections()
        for item in items:
            directory = self.getDirectory(item)
            self.runTermDir(directory)

    def runTerm(self):
        item = self.tree_ctrl_1.GetSelection()
        directory = self.getDirectory(item)
        self.runTermDir(directory)
        
    def runTermDir(self, directory):
        comm =  "cd " + directory + ";"
        comm += "gnome-terminal &"
        os.system(comm.encode("utf-8"))

    def checkApp(self, directory, App):
        flag = "NG"
        names = glob.glob(directory + "/" + App)
        if len(names) == 1:
            flag = "OK"
        else:
            names = glob.glob(App)
            if len(names) == 1:
                flag = "OK"
            else:
                paths = os.environ["PATH"].split(":")
                for path in paths:
                    names = glob.glob(path + "/" + App)
                    if len(names) == 1:
                        flag = "OK"
                        break
        return flag


    def runHelyxos(self):
        global solveCaseFix
        if OFversionFix >= "2.2.0":
            comm = "runHelyxosDialog220.py " + solveCaseFix + "&"
        else:
            comm = "runHelyxosDialog.py " + solveCaseFix + "&"
        os.system(comm)

    def runParaFoamDir(self, directory):
        global paraFoamFix
        if checkFolder(directory) == "case":
            if self.checkApp(directory, paraFoamFix) == "OK":
                comm = "runParaFoamOptionDialog.py " + paraFoamFix + " " + directory + " &"
                pyTreeFoam.runCommand(comm.encode("utf-8"))
            else:
                title = _(u"エラー")
                message = _(u"「") + paraFoamFix + _(u"」は、存在しません。\n")
                message = message + _(u"実行fileが間違っています。")
                self.errDialog(title, message)
        else:
            title = _(u"エラー")
            message = _(u"指定されたフォルダ「") + directory + _(u"」は、OpenFOAMのCaseではありません。")
            self.errDialog(title, message)


    def runSalomeMeca(self, directory):
        global salomeMecaFix
        if self.checkApp(directory, salomeMecaFix) == "OK":
            comm = salomeMecaFix + " " + directory
            pyTreeFoam.runCommand(comm.encode("utf-8"))
        else:
            title = _(u"エラー")
            message = _(u"「") + salomeMecaFix + _(u"」は、存在しません。\n")
            message = message + _(u"実行fileが間違っています。")
            self.errDialog(title, message)

    def runCAD(self, directory):
        global cadFix
        if self.checkApp(directory, cadFix) == "OK":
            comm = cadFix + " " + directory + " &"
            pyTreeFoam.runCommand(comm)
        else:
            title = _(u"エラー")
            message = _(u"「") + cadFix + _(u"」は、存在しません。\n")
            message = message + _(u"実行fileが間違っています。")
            self.errDialog(title, message)

    def changeStopAt(self, caseDir):
        global stopAt, endTime
        endCont = self.combo_box_2.GetValue()
        writeCont = []
        if endCont[:len("endTime")] == "endTime":
            if len(endCont.split(":")) == 2:
                newStopAt = endCont.split(":")[0]
                if newStopAt != stopAt:
                    stopAt = newStopAt
                    writeCont.append(["stopAt", stopAt])
                newEndTime = endCont.split(":")[1]
                if newEndTime != endTime:
                    endTime = newEndTime
                    writeCont.append(["endTime", endTime])
        else:
            newStopAt = endCont
            if newStopAt != stopAt:
                stopAt = newStopAt
                writeCont.append(["stopAt", stopAt])
        if len(writeCont) != 0:
            wdir = caseDir + "/system"
            setFoamContents.controlDict(wdir, writeCont)
            self.setSolverStopTime(caseDir)        #combo_box_2のlist内容を修正
            title = _(u"controlDictの書き換え")
            mess = _(u"controlDictを書き換えました")
            self.okDialog(title, mess)

    def changeTimeFolder(self, caseDir):
        global latestTime, startTime, firstTime, startFrom
        timeCont = self.combo_box_1.GetValue()
        startItems = timeCont.split(":")
        startItem = startItems[0].split()[0]
        if len(startItems) == 2:
            time = startItems[1]
        else:
            time = ""
        wdir = caseDir + "/system"
        items = []
        if startItem != startFrom:
            wdir = caseDir + "/system"
            items = [["startFrom", startItem]]
        if startItem == "startTime":
            items.append(["startTime", time])
        if len(items) != 0:
            setFoamContents.controlDict(wdir, items)
            self.setEditTimeFolder(caseDir)     #combo_box_1のlist内容を修正
            title = _(u"controlDictの書き換え")
            mess = _(u"controlDictを書き換えました")
            self.okDialog(title, mess)


    #---------config------------------------
    #
    # getConfig
    #
    def getConfig(self):
        global rootDirFix, selCaseDirFix
        global rootDir, selCaseDir, configFile

        rootDir = rootDirFix
        selCaseDir = selCaseDirFix

        message = ""
        if rootDir == "":
            rootDir = os.path.expanduser("~")
            rootDirFix = rootDir
            message = message + _(u"rootDirが設定されていません。rootDirとしてhomeDirを設定しました。\n")
        if selCaseDir == "":
            selCaseDir = rootDir
            selCaseDirFix = selCaseDir
            message = message + _(u"selCaseDirが設定されていません。selCaseDirとしてrootDirを設定しました。\n")
        if message != "":
            title = _(u"エラー")
            self.errDialog(title, message)

    def saveRootDirToConfig(self, dirName):
        global rootDirFix
        rootDirFix = dirName

    def saveSelCaseDirToConfig(self, dirName):
        global selCaseDirFix
        selCaseDirFix = dirName


    #
    #  readConfig
    #    configFileの読み込み
    def readConfig(self):
        global rootDirFix, solveCaseFix, selCaseDirFix, configFile, paraFoamFix
        global treeFoamPath, salomeMecaFix, envOpenFOAMFix, cadFix, OFversionFix
        global editor, helyxosFix, languageFix
        #configFileの読み込み
        configData = pyTreeFoam.readConfigTreeFoam()
        #変数をセット
        OFversionFix = configData[0]
        envOpenFOAMFix = configData[1]
        rootDirFix = configData[2]
        solveCaseFix = configData[3]
        paraFoamFix = configData[4]
        salomeMecaFix = configData[5]
        cadFix = configData[6]
        editor = configData[7]
        helyxosFix = configData[8]
        languageFix = configData[9]
        selCaseDirFix = solveCaseFix

        #serverマウント有無を確認
        data = pyTreeFoam.readSshfsData()
        mountDir = data[3]
        if mountDir != "":
            if mountDir == solveCaseFix[:len(mountDir)]:
                words = mountDir.split("/")
                if len(words)<1:
                    solveCaseFix = rootDirFix
                    selCaseDirFix = rootDirFix
                else:
                    solveCaseFix = "/".join(words[:-1])
                    selCaseDirFix = solveCaseFix

        if len(glob.glob(rootDirFix)) == 0:
            rootDir = os.environ["HOME"]
            rootDirFix = rootDir
            print _(u"rootDirが設定されていなかったので、homeDirに設定しました。")
        if len(glob.glob(solveCaseFix)) == 0:
            #solveCaseFix = treeFoamPath
            solveCaseFix = rootDirFix
            selCaseDirFix = solveCaseFix
            print _(u"解析caseDirが設定されていなかったので、TreeFoamに設定しました。")

    #
    #  writeConfig
    #    configFileの書き込み
    def writeConfig(self):
        global rootDirFix, solveCaseFix, selCaseDirFix, configFile, treeFoamPath
        #os.chdir(treeFoamPath)
        configFile = os.getenv("TreeFoamUserPath") + "/configTreeFoam"
        f= codecs.open(configFile, "r", "utf-8")
        configContents = f.readlines()
        f.close()

        #rootDirの置き換え
        i=0
        flag = 0
        for line in configContents:
            word = line.split()
            if (len(word) > 0):
                if (word[0] == "rootDir"):
                    if type(rootDirFix) == str:
                        rootDirFix = rootDirFix.decode("utf-8")
                    configContents[i] = word[0] + "   " + rootDirFix + "\n"
                    flag = 1
                    break
            i=i+1
        if flag == 0:
            configContents.append("rootDir   " + rootDirFix + "\n")

        #solveCaseの置き換え
        i=0
        flag = 0
        for line in configContents:
            word = line.split()
            if (len(word) > 0):
                if (word[0] == "workDir"):
                    if type(solveCaseFix) == str:
                        solveCaseFix = solveCaseFix.decode("utf-8")
                    configContents[i] = word[0] + "   " + solveCaseFix + "\n"
                    flag = 1
                    break
            i=i+1
        if flag == 0:
            configContents.append("workDir   " + solveCaseFix + "\n")

        #ファイルに書込
        fu = codecs.open(configFile, "w", "utf-8")
        for line in configContents:
            fu.write(line)
        fu.close()


    #----------universal dialog-------------
    def okDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                               style = wx.OK | wx.ICON_INFORMATION) 
        dlg.ShowModal()
        dlg.Destroy()

    def okCancelDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                             wx.OK | wx.CANCEL | wx.ICON_INFORMATION) 
        ans = dlg.ShowModal()
        stat = ""
        if ans == wx.ID_OK:
            #dlg.Destroy()
            stat = "OK"
            #return "OK"
        else:
            #dlg.Destroy()
            stat = "CANCEL"
            #return "CANCEL"
        return stat

    def yesNoDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                             wx.YES | wx.NO | wx.ICON_INFORMATION) 
        ans = dlg.ShowModal()
        stat = ""
        if ans == wx.ID_YES:
            stat = "YES"
        else:
            stat = "NO"
        return stat


    def errDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                               style = wx.OK | wx.ICON_HAND) 
        dlg.ShowModal()
        dlg.Destroy()

    def warningDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                               style = wx.OK | wx.ICON_QUESTION) 
        dlg.ShowModal()
        dlg.Destroy()

    def textDialog(self, title, message, defText):
        dlg = wx.TextEntryDialog(self, message, title, defaultValue=defText)
        ansBtn = dlg.ShowModal()
        ansTxt = dlg.GetValue()
        if ansBtn == wx.ID_OK:
            text = ansTxt
        else:
            text = ""
        return text

    def writeStatus(self, text):
        self.frame_1_statusbar.SetStatusText(text)

    def clearStatus(self):
        global selectTreeDir
        path = selectTreeDir
        if path == "" or len(glob.glob(path))==0:
            path = "/home"
        s = os.statvfs(path.encode("utf-8"))
        #total = (int(((s.f_frsize * s.f_blocks) / 1024.0**3) * 100.0))/100.0
        #avail = (int(((s.f_frsize * s.f_bavail) / 1024.0**3) * 100.0))/100.0
        #合計
        total = (int(((s.f_frsize * s.f_blocks) / 1000.0**3) * 100.0))/100.0
        #利用可能な空き領域
        avail = (int(((s.f_frsize * s.f_bavail) / 1000.0**3) * 100.0))/100.0
        #空き領域（合計）
        favail = (int(((s.f_frsize * s.f_favail) / 1024.0**3) * 100.0))/100.0
        msg = _(u"合計 ") + str(total) + _(u" GB,  空き ") + str(avail) + " GB"
        self.frame_1_statusbar.SetStatusText(msg)

# end of class MyFrame


#
#  getEditTimeFolder
#    controlDictの内容に従ったtimeFolderを取得
def getEditTimeFolder(caseDir):
    timeFolder = ""
    timeFolders = pyTreeFoam.getTimeFolders(caseDir)
    wdir = solveCaseFix+"/system"
    items = getFoamContents.controlDict(wdir, ["startFrom", "startTime"])
    if len(timeFolders) != 0 and items != None:
        if items[0] == "firstTime":
            timeFolder = timeFolders[0]
        elif items[0] == "latestTime":
            timeFolder = timeFolders[-1]
        else:
            if len(items) > 1:
                timeFolder = items[1]
                if len(glob.glob(caseDir + "/" + timeFolder)) == 0:
                    timeFolder = timeFolders[0]
            else:
                timeFolder = timeFolders[0]
    return timeFolder

def getSolver(selectDir):
    fileName = selectDir + "/system/controlDict"
    solver = ""
    if os.path.isfile(fileName) == True:
        f=open(fileName)
        for line in f.readlines():
            lineList = line.split()
            if len(lineList) >= 2:
                if lineList[0] == "application":
                    solver = lineList[1]
                    if solver[-1] == ";":
                        solver = solver[:-1]
                    break
        f.close()
    return solver

def getSolverBC(selectDir):
    fileName = selectDir + "/system/controlDict"
    solver = ""
    BCb = ""
    BCc = ""
    if os.path.isfile(fileName) == True:
        f=open(fileName)
        flag = 0
        for line in f.readlines():
            lineList = line.split()
            if len(lineList) >= 2:
                if lineList[0] == "application":
                    solver = getItemCont(lineList[1])
                    flag += 1
                elif lineList[0] == "writeFormat":
                    wformat = getItemCont(lineList[1])
                    if wformat == "binary":
                        BCb = "B"
                    else:
                        BCb = "a"
                    flag += 1
                elif lineList[0] == "writeCompression":
                    comp = getItemCont(lineList[1])
                    if comp == "compressed" or comp == "yes" or comp == "on":
                        BCc = "C"
                    else:
                        BCc = "n"
                    flag += 1
            if flag >= 3:
                break
        f.close()
    BC = BCb + BCc
    return [solver, BC]

def getItemCont(cont):
    if cont[-1] == ";":
        ans = cont[:-1]
    else:
        if len(cont) > 0:
            ans = cont
        else:
            ans = ""
    return ans

#
#  getNumberResult
#    計算結果folderの数を取得
def getNumberResult(selectDir):
    folders = getFoldersOnlyCurrDir(selectDir)
    ans = []
    for folder in folders:
        try:
            a = float(folder.split("/")[-1])
            ans.append(a)
        except:
            a = 1.0
    nRst = len(ans)
    if nRst < 2:
        for folder in folders:
            if folder.split("/")[-1] == "processor0":
                subFolders = getFoldersOnlyCurrDir(selectDir + "/processor0")
                ans = []
                for subFolder in subFolders:
                    try:
                        a = float(subFolder.split("/")[-1])
                        ans.append(a)
                    except:
                        a = 1.0
                nRst = len(ans)
                break
    #並列数を確認
    ip = 0
    for folder in folders:
        if folder.split("/")[-1][:len("processor")] == "processor":
            ip += 1
    #戻り値を設定
    ansR = []
    if nRst != 0:
        ansR.append(" " + str(nRst))
        ansR.append(" " + str(min(ans)))
        if min(ans) == max(ans):
            ansR.append("")
        else:
            ansR.append(" " + str(max(ans)))
        if ip == 0:
            ansR.append(" ")
        else:
            ansR.append(str(ip))
    return ansR

#
#  checkFolder
#    folderのチェック
def checkFolder(folderDir):
    ans = ""
    if os.path.isdir(folderDir) == True:
        ans = "folder"
        folderName = folderDir.split("/")[-1]
        try:
            a=float(folderName)
            #数字フォルダ
            ans = "hide"
        except:
            if (folderName == "system" or
            folderName == "constant" or
            #folderName == "model" or
            folderName == "solve.log.analyzed" or
            folderName[0] == "."):
                #禁止フォルダ
                ans = "hide"
            else:
                controlDict = folderDir + "/system/controlDict"
                if os.path.isfile(controlDict)==True:
                    #caseフォルダ
                    ans = "case"
                elif len(glob.glob(folderDir+"/*.hdf")) != 0:
                    ans = "salome" 
    else:
        #ファイル
        ans = "file"
    return ans


#
#  getTreeDirOnlylRootChildren
#
def getTreeDirOnlylRootChildren(rootDir):
    #global treeData
    treeData = pyTreeFoam.getTreeDirOnlylRootChildren(rootDir)
    return treeData

#
#  getTreeDirUntilCurrCase
#    currCaseまでのtreeデータ取得
#
def getTreeDirUntilCurrCase(rootDir, selCaseDir):
    global treeData, selCase
    #treeDataの取得
    treeData = pyTreeFoam.getTreeDirUntilCurrCase(rootDir, selCaseDir)
    #selCaseの設定
    selCaseNames = selCaseDir[len(rootDir)+1:].split("/")
    selCase=[]
    selCase.append(rootDir)
    for name in selCaseNames:
        selCase.append(name)

#
#　getFoldersOnlyCurrDir
#  　currDirのみのFolderを取得する
#
def getFoldersOnlyCurrDir(currDir):
    folders = []
    try:
        allItem = os.listdir(currDir)
        for item in allItem:
            newFolder = currDir + "/" + item
            if os.path.isdir(newFolder) == True:
                folders.append(newFolder)
    except:
        folders=[]
    return folders


#
#  endingTreeFoam
#    TreeFoamの終了処理
def endingTreeFoam(treeSize, colWidth, splitWidth):
    # TreeFoamの起動番号（nTreeFoam）を削除
    #fileName = treeFoamPath + "/" + nRunningTreeFoam
    fileName = os.getenv("TreeFoamUserPath") + "/" + nRunningTreeFoam
    f=open(fileName); contents=f.readlines(); f.close()
    newNoList = []
    for line in contents:
        NoList=line.split()
        if len(NoList) != 0:
            No = int(NoList[0])
            if No != int(nTreeFoam):
                newNoList.append(line)
    f=open(fileName,"w")
    for line in newNoList:
        f.write(line)
    f.close()
    #windowSizeの書き込み
    saveTreeSize(treeSize, colWidth, splitWidth)
    #logFile削除
    logFile = os.environ["LogFile"]
    if os.path.isfile(logFile) == True:
        comm = "rm -f " + logFile
        os.system(comm)


#  saveTreeSize
#    treeFoamのwindowSizeを保存
def saveTreeSize(treeSize, colWidth, splitWidth):
    (h, w) = treeSize
    #fileName = os.environ["TreeFoamPath"] + "/" + winSizeFile
    fileName = os.environ["TreeFoamUserPath"] + "/" + winSizeFile
    contents = []
    if len(glob.glob(fileName)) != 0:
        f=open(fileName); contents=f.readlines(); f.close()
        i=0; flag=0; flagCol = 0; flagSplit = 0
        for line in contents:
            words = line.split()
            if words[0] == "treeFoam":
                words[1] = str(h)
                words[2] = str(w)
                contents[i] = words[0] + " " + words[1] + " " + words[2] + "\n"
                flag = 1
            elif words[0] == "treeFoam_colWidth":
                contents[i] = words[0]
                contents[i] += " " + str(colWidth[0])
                contents[i] += " " + str(colWidth[1])
                contents[i] += " " + str(colWidth[2])
                contents[i] += " " + str(colWidth[3])
                contents[i] += " " + str(colWidth[4])
                contents[i] += " " + str(colWidth[5]) + "\n"
                flagCol = 1
            elif words[0] == "treeFoam_splitter":
                if splitWidth >= 0:
                    contents[i] = words[0] + " " + str(splitWidth) + "\n"
                flagSplit = 1
            if flag == 1 and flagCol == 1 and flagSplit == 1:
                break
            i += 1
        if flag == 0:
            line = "treeFoam " + str(h) + " " + str(w) + "\n"
            contents.append(line)
        if flagCol == 0:
            line = "treeFoam_colWidth "
            line += " " + str(colWidth[0])
            line += " " + str(colWidth[1])
            line += " " + str(colWidth[2])
            line += " " + str(colWidth[3])
            line += " " + str(colWidth[4])
            line += " " + str(colWidth[5]) + "\n"
            contents.append(line)
        if flagSplit == 0:
            line = "treeFoam_splitter "
            if splitWidth >= 0:
                line += str(splitWidth) + "\n"
            else:
                line += str(int(h*0.8)) + "\n"
            contents.append(line)
    else:
        line = "treeFoam " + str(h) + " " + str(w) + "\n"
        contents.append(line)
        line = "treeFoam_colWidth "
        line += " " + str(colWidth[0])
        line += " " + str(colWidth[1])
        line += " " + str(colWidth[2])
        line += " " + str(colWidth[3])
        line += " " + str(colWidth[4])
        line += " " + str(colWidth[5]) + "\n"
        contents.append(line)
        line = "treeFoam_splitter "
        if splitWidth >= 0:
            line += str(splitWidth) + "\n"
        else:
            line += str(int(h*0.8)) + "\n"
        contents.append(line)
    f=open(fileName, "w")
    for line in contents:
        f.write(line)
    f.close()


#  getTreeFoamInstallDir
#    treeFoamのインストールdirを取得
def getTreeFoamInstallDir():
    homeFolder = os.path.expanduser("~")
    fileName = homeFolder + "/.treeFoamInstallFolder"
    f=open(fileName); treeFoamDir=f.readline(); f.close()
    return treeFoamDir

# initializeTreeFoam
#   初期化
def initializeTreeFoam():
    global treeFoamPath, nTreeFoam, version, clipBoard, treeSize, languageFix
    global splitWidth, sshfsDir
    startFile.write("initializing...\n")
    #言語の設定
    treeFoamPath = os.getenv("TreeFoamPath")
    homeFolder = os.path.expanduser("~")
    fileName = homeFolder + "/.treeFoamInstallFolder"
    if len(glob.glob(fileName)) == 0:
        #隠しfileがなかった場合(install後の初めての起動)、環境に合わせて設定
        lang = os.environ["LANG"]
        if lang[:2] != "ja":
            languageFix = "English"
        else:
            languageFix = "Japanese"
        setLangToConfig(languageFix)
    #言語をconfigFileに合わせる
    ans = pyTreeFoam.readConfigTreeFoam()
    setLanguage(ans[9])
    #treeFoamのインストールフォルダの取得、隠しファイル作成
    f=open(fileName, "w")
    f.write(treeFoamPath)
    f.close()
    #sshfsDir（focusをマウントするdir）を設定
    fileName = os.getenv("TreeFoamUserPath") + "/data/sshfs_data"
    if len(glob.glob(fileName)) == 0:
        cpFileName = os.getenv("TreeFoamPath") + "/data/sshfs_data"
        pasteFolder = os.getenv("TreeFoamUserPath") + "/data"
        comm = "cp " + cpFileName + " " + pasteFolder
        os.system(comm)
    data = pyTreeFoam.readSshfsData()
    sshfsDir = data[3]
    #sshfsDirが存在しない場合は、「""」に設定
    if len(glob.glob(sshfsDir)) == 0:
        sshfsDir = ""
    #sshfsDirを設定
    if sshfsDir != "" :
        files = os.listdir(sshfsDir)
        if len(files) == 0:
            sshfsDir = ""
        else:
            flag = 0
            for name in files:
                if name == ".bashrc" or name == ".ssh":
                    flag += 1
            if flag != 2:
                sshfsDir = ""
        if sshfsDir == "":
            data[3] = sshfsDir
            pyTreeFoam.writeSshfsData(data)
    #TreeFoamの起動No取得
    fileName = os.getenv("TreeFoamUserPath") + "/" + nRunningTreeFoam
    try:
        f=open(fileName); contents = f.readlines(); f.close()
    except:
        contents = []
    No = -1
    for line in contents:
        NoList = line.split()
        if len(NoList) != 0:
            No = int(NoList[0])
    nTreeFoam = str(No + 1)
    contents.append(nTreeFoam + "\n")
    f=open(fileName,"w")
    for line in contents:
        f.write(line)
    f.close()
    #clipBoardを定義
    try:
        clipBoardPath = os.environ["TreeFoamUserPath"] + "/data"
    except:
        clipBoardPath = os.environ["HOME"]
    clipBoard = clipBoardPath + "/clipBoard"
    #TeeFoamのバージョンを記録
    verFileName = os.getenv("TreeFoamPath") + "/TreeFoamVersion"
    f=open(verFileName); lines=f.readlines(); f.close()
    recVersion = getRecTreeFoamVersion(lines)
    if recVersion != version:
        newLines = setRecTreeFoamVersion(version, lines)
        f=open(verFileName, "w")
        for line in newLines:
            f.write(line)
        f.close()
    #windowSizeの読み込み
    treeSize = getTreeSize()
    #OpenFOAMのバージョンを記録
    bashrc = pyTreeFoam.getBashrcFoam()
    comm = ". " + bashrc
    [stat, cont] = pyTreeFoam.runCommandErrorCheck(comm)
    if stat == "ERROR":
        print "OpenFOAM - XXXX"
        comm = "getOFversionWriteConfig.py"
        pyTreeFoam.runCommand(comm)
    else:
        comm = "getOFversionWriteConfig.py"
        pyTreeFoam.runOFUtility(comm)
    config = pyTreeFoam.readConfigTreeFoam()
    OFversionFix = config[0]
    #logFileを設定
    home = os.environ["HOME"]
    wdir = os.environ["LogFile"]
    log = os.getenv("log")
    if log != "no":
        os.environ["LogFile"] = wdir + "/" + nTreeFoam + "_logTreeFoam"
    else:
        os.environ["LogFile"] = home
    import logFileCreater
    logFileCreater.new()
    print "TreeFoam ver", version, " (" + nTreeFoam + ") " + _(u"を起動しました。")
    print "OpenFOAM -", OFversionFix

def getRecTreeFoamVersion(lines):
    recVersion = ""
    for line in lines:
        words = line.split()
        if len(words) > 1:
            if words[0] == "currentTreeFoamVersion":
                recVersion = words[1]
                break
    return recVersion

def setRecTreeFoamVersion(version, lines):
    flag = 0
    for i in range(len(lines)):
        words = lines[i].split()
        if len(words) > 1:
            if words[0] == "currentTreeFoamVersion":
                words[1] = version
                lines[i] = " ".join(words) + "\n"
                flag = 1
                break
    if flag == 0:
        line = "currentTreeFoamVersion " + version + "\n"
        lines = [line] + lines
    return lines

def setLanguage(lang):
    treeFoamPath = os.environ["TreeFoamPath"]
    if lang == "English":
        os.environ["LANG"] = "en_US.UTF-8"
        os.environ["LANGUAGE"] = "en_US.UTF-8"
        gettext.install("treefoam", treeFoamPath + "/data/locale")
    else:
        os.environ["LANG"] = "ja_JP.UTF-8"
        os.environ["LANGUAGE"] = "ja_JP.UTF-8"
        gettext.install("", treeFoamPath + "/data/locale")
    return

def setLangToConfig(language):
    treeFoamPath = os.environ["TreeFoamPath"]
    config = treeFoamPath + "/" + configFile
    f=open(config); lines=f.readlines(); f.close()
    for i in range(len(lines)):
        line = lines[i]
        words = line.split()
        if len(words) >= 2:
            if words[0] == "language":
                words[1] = language
                lines[i] = " ".join(words) + "\n"
                break
    f=open(config, "w")
    for line in lines:
        f.write(line)
    f.close()

def getTreeSize():
    global treeSize, colWidth, splitWidth
    ans = treeSize
    #fileName = os.environ["TreeFoamPath"] + "/" + winSizeFile
    fileName = os.environ["TreeFoamUserPath"] + "/" + winSizeFile
    if len(glob.glob(fileName)) != 0:
        f = open(fileName); lines = f.readlines(); f.close()
        for line in lines:
            words = line.split()
            if len(words) == 3:
                if words[0] == "treeFoam":
                    ans = (int(words[1]), int(words[2]))
            if len(words) >= 6:
                if words[0] == "treeFoam_colWidth":
                    colWidth[0] = int(words[1])
                    colWidth[1] = int(words[2])
                    colWidth[2] = int(words[3])
                    colWidth[3] = int(words[4])
                    colWidth[4] = int(words[5])
                    colWidth[5] = int(words[6])
            if len(words) == 2:
                if words[0] == "treeFoam_splitter":
                    splitWidth = int(words[1])
    return ans


def clearStartingScreen():
    startFile.write("close\n")
    startFile.close()

#-------- clipBoard使用の為、追加 ----------------
#
#  uris_to_paths
#    URIをpathに変換
def uris_to_paths(uris):
    paths = []
    for uri in uris:
        if uri.startswith(u"file:/"):
            uri = uri[5:]
            while uri.startswith("//"):
                uri = uri[1:]
            paths.append(urllib.unquote(uri))
    return paths

#
#  paths_to_uris
#    path名をURIに変換
def paths_to_uris(paths):
    uris = []
    for path in paths:
        uri = u"file://" + urllib.quote(path)
        uris.append(uri)
    return uris

#
#  sysCopyFolders
#    systemClipBoardへコピー
def sysCopyFolders(folders):
    action = "copy"

    def get_func(sysClipboard, selectiondata, info, data):
        txt = action + "\n" + "\n".join(paths_to_uris(folders))
        selectiondata.set(selectiondata.get_target(), 8, txt)

    def clear_func(sysClipboard,data):
        print "clear_func"

    targets = [ ('x-special/gnome-copied-files', 0, 0), ("text/uri-list", 0, 0) ]
    ret = sysClipboard.set_with_data(targets, get_func, clear_func)

#
#  sysPasteFolders
#    systemClipBoardをペースト
def sysPasteFolders(pasteDir):
    destination = pasteDir

    def callback(clipboard, selectiondata, udata):
        lines = selectiondata.data.splitlines()
        action = lines[0].rstrip()
        uris = lines[1:]
        files = uris_to_paths(uris)
        for file in files:
            #shutil.copy(file, destination)
            comm = "cp -fr " + file + " " + destination
            os.system(comm)

    def callback_targets(clipboard, targets, data):
        print "targets", targets

    sysClipboard.request_contents("x-special/gnome-copied-files", callback)
#-------------------------------------------------


if __name__ == "__main__":
    #国際化（言語の設定）
    import gettext
    treeFoamPath = os.environ["TreeFoamPath"]
    gettext.install("treefoam", treeFoamPath + "/data/locale")

    #初期化
    initializeTreeFoam()
    #表示
    #app = wx.PySimpleApp(False)
    app = wx.App(0)
    #wx.InitAllImageHandlers()
    frame_1 = MyFrame(None, -1, "")
    app.SetTopWindow(frame_1)
    frame_1.Show()
    frameShow = "showing"
    #starting画面消去
    clearStartingScreen()
    app.MainLoop()
    #gtk.main()

